@@ -137,9 +137,27 @@ class QueryType(Enum):
     SETTLEMENT_PRICE = "Settlement Price"
     THEMATIC_EXPOSURE = "Thematic Exposure"
     THEMATIC_BETA = "Thematic Beta"
+    THEMATIC_MODEL_BETA = "Thematic Model Beta"
     CDS_SPREAD_100 = "Spread At100"
     CDS_SPREAD_250 = "Spread At250"
     CDS_SPREAD_500 = "Spread At500"
+    STRIKE_VOL = "Strike Vol"
+    OPTION_PREMIUM = "Option Premium"
+    ABSOLUTE_STRIKE = "Absolute Strike"
+    RETAIL_PCT_SHARES = 'impliedRetailPctShares'
+    RETAIL_PCT_NOTIONAL = 'impliedRetailPctNotional'
+    RETAIL_SHARES = 'impliedRetailShares'
+    RETAIL_NOTIONAL = 'impliedRetailNotional'
+    SHARES = 'shares'
+    NOTIONAL = 'notional'
+    RETAIL_BUY_NOTIONAL = 'impliedRetailBuyNotional'
+    RETAIL_BUY_PCT_NOTIONAL = 'impliedRetailBuyPctNotional'
+    RETAIL_BUY_PCT_SHARES = 'impliedRetailBuyPctShares'
+    RETAIL_BUY_SHARES = 'impliedRetailBuyShares'
+    RETAIL_SELL_NOTIONAL = 'impliedRetailSellNotional'
+    RETAIL_SELL_PCT_NOTIONAL = 'impliedRetailSellPctNotional'
+    RETAIL_SELL_PCT_SHARES = 'impliedRetailSellPctShares'
+    RETAIL_SELL_SHARES = 'impliedRetailSellShares'
 
 
 class GsDataApi(DataApi):
@@ -257,6 +275,16 @@ class GsDataApi(DataApi):
         result = GsSession.current._post('/data/datasets', payload=definition)
         return result
 
+    @classmethod
+    def delete_dataset(cls, dataset_id: str) -> dict:
+        result = GsSession.current._delete(f'/data/datasets/{dataset_id}')
+        return result
+
+    @classmethod
+    def undelete_dataset(cls, dataset_id: str) -> dict:
+        result = GsSession.current._put(f'/data/datasets/{dataset_id}/undelete')
+        return result
+
     @classmethod
     def update_definition(cls, dataset_id: str, definition: Union[DataSetEntity, dict]) -> DataSetEntity:
         result = GsSession.current._put('/data/datasets/{}'.format(dataset_id), payload=definition, cls=DataSetEntity)
@@ -266,7 +294,7 @@ class GsDataApi(DataApi):
     def upload_data(cls, dataset_id: str, data: Union[pd.DataFrame, list, tuple]) -> dict:
         if isinstance(data, pd.DataFrame):
             # We require the Dataframe to return a list in the 'records' format:
-            # https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_json.html
+            #  https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_json.html
             data = data.to_json(orient='records')
         result = GsSession.current._post('/data/{}'.format(dataset_id), payload=data)
         return result
@@ -688,7 +716,8 @@ class GsDataApi(DataApi):
             **kwargs
         )
 
-        ret = tuple(pd.Series() if df.empty else pd.Series(index=df.index, data=df.value.values) for df in dfs)
+        ret = tuple(pd.Series(dtype=float) if df.empty else pd.Series(index=df.index, data=df.value.values)
+                    for df in dfs)
         if isinstance(coordinates, (MarketDataCoordinate, str)):
             return ret[0]
         else:
