@@ -20,7 +20,7 @@ from typing import Tuple, Union, List, Dict
 from gs_quant.common import PositionType
 from gs_quant.instrument import Instrument
 from gs_quant.session import GsSession
-from gs_quant.target.common import RiskRequest
+from gs_quant.target.common import RiskRequest, Currency
 from gs_quant.target.portfolios import Portfolio, Position, PositionSet
 from gs_quant.target.reports import Report
 from gs_quant.target.risk_models import Term
@@ -94,21 +94,33 @@ class GsPortfolioApi:
         return position_sets[0] if len(position_sets) > 0 else None
 
     @classmethod
-    def get_instruments_by_position_type(cls, positions_type: str,
-                                         positions_id: str) -> Tuple[Instrument, ...]:
+    def get_position_set_by_position_type(cls, positions_type: str, positions_id: str,
+                                          activity_type: str = 'position') -> Tuple[Instrument, ...]:
         root = 'deals' if positions_type == 'ETI' else 'books/' + positions_type
-        url = '/risk-internal/{}/{}/positions'.format(root, positions_id)
+        if activity_type != 'position':
+            url = '/risk-internal/{}/{}/positions?activityType={}'.format(root, positions_id, activity_type)
+        else:
+            url = '/risk-internal/{}/{}/positions'.format(root, positions_id)
         results = GsSession.current._get(url, timeout=181)
+        return tuple(PositionSet.from_dict(res) for res in results['positionSets'])
+
+    @classmethod
+    def get_instruments_by_position_type(cls, positions_type: str,
+                                         positions_id: str,
+                                         activity_type: str) -> Tuple[Instrument, ...]:
+        position_sets = cls.get_position_set_by_position_type(positions_type=positions_type,
+                                                              positions_id=positions_id,
+                                                              activity_type=activity_type)
 
         instruments = []
-        for position in results.get('positionSets', ({'positions': ()},))[0]['positions']:
-            instrument_values = position['instrument']
-            instrument = Instrument.from_dict(instrument_values)
-            name = instrument_values.get('name')
-            if name:
-                instrument.name = name
-
-            instruments.append(instrument)
+        for position_set in position_sets:
+            for positions in position_set.positions:
+                instrument = positions.instrument
+                instrument.metadata = {
+                    'trade_date': position_set.position_date, 'tags': positions.tags,
+                    'external_ids': {id['idType']: id['idValue'] for id in positions.external_ids},
+                    'party_from': positions.party_from, 'party_to': positions.party_to}
+                instruments.append(instrument)
 
         return tuple(instruments)
 
@@ -149,8 +161,12 @@ class GsPortfolioApi:
         return tuple(dt.datetime.strptime(d, '%Y-%m-%d').date() for d in position_dates)
 
     @classmethod
-    def update_positions(cls, portfolio_id: str, position_sets: List[PositionSet]) -> float:
-        return GsSession.current._put('/portfolios/{id}/positions'.format(id=portfolio_id), position_sets)
+    def update_positions(cls,
+                         portfolio_id: str,
+                         position_sets: List[PositionSet],
+                         net_positions: bool = True) -> float:
+        url = f'/portfolios/{portfolio_id}/positions?netPositions={str(net_positions).lower()}'
+        return GsSession.current._put(url, position_sets)
 
     @classmethod
     def get_positions_data(cls,
@@ -207,7 +223,7 @@ class GsPortfolioApi:
     def get_schedule_dates(cls,
                            portfolio_id: str,
                            backcast: bool = False) -> List[dt.date]:
-        results = GsSession.current._get(f'/portfolios/{portfolio_id}/schedule/dates?backcast={backcast}')
+        results = GsSession.current._get(f'/portfolios/{portfolio_id}/schedule/dates?backcast={str(backcast).lower()}')
         return [dt.datetime.strptime(results['startDate'], '%Y-%m-%d').date(),
                 dt.datetime.strptime(results['endDate'], '%Y-%m-%d').date()]
 
@@ -233,3 +249,18 @@ class GsPortfolioApi:
         if clear_existing_data:
             url += '?clearExistingData=true'
         return GsSession.current._post(url, payload)
+
+    @classmethod
+    def get_attribution(cls,
+                        portfolio_id: str,
+                        start_date: dt.date = None,
+                        end_date: dt.date = None,
+                        currency: Currency = None) -> Dict:
+        url = f'/attribution/{portfolio_id}?'
+        if start_date:
+            url += f"&startDate={start_date.strftime('%Y-%m-%d')}"
+        if end_date:
+            url += f"&endDate={end_date.strftime('%Y-%m-%d')}"
+        if currency:
+            url += f"currency={currency.value}"
+        return GsSession.current._get(url)['results']
