@@ -27,20 +27,23 @@ from pydash import get
 
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.carbon import CarbonCard, GsCarbonApi, CarbonTargetCoverageCategory, CarbonScope, \
-    CarbonEmissionsAllocationCategory, CarbonEmissionsIntensityType, CarbonCoverageCategory, CarbonEntityType
+    CarbonEmissionsAllocationCategory, CarbonEmissionsIntensityType, CarbonCoverageCategory, CarbonEntityType, \
+    CarbonAnalyticsView
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.api.gs.esg import ESGMeasure, GsEsgApi, ESGCard
+from gs_quant.api.gs.indices import GsIndexApi
 from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.api.gs.reports import GsReportApi
+from gs_quant.api.gs.thematics import ThematicMeasure, GsThematicApi, Region
 from gs_quant.common import DateLimit, PositionType, Currency
 from gs_quant.data import DataCoordinate, DataFrequency, DataMeasure
 from gs_quant.data.coordinate import DataDimensions
-from gs_quant.datetime import business_day_offset
 from gs_quant.entities.entitlements import Entitlements
 from gs_quant.errors import MqError, MqValueError
 from gs_quant.markets.indices_utils import BasketType, IndicesDatasets
-from gs_quant.markets.position_set import PositionSet
-from gs_quant.markets.report import PerformanceReport, FactorRiskReport, Report, ThematicReport
+from gs_quant.markets.position_set import PositionSet, Position
+from gs_quant.markets.report import PerformanceReport, FactorRiskReport, Report, ThematicReport, \
+    flatten_results_into_df, get_thematic_breakdown_as_df
 from gs_quant.models.risk_model import FactorRiskModel
 from gs_quant.session import GsSession
 from gs_quant.target.data import DataQuery
@@ -59,6 +62,7 @@ class EntityType(Enum):
     REPORT = 'report'
     RISK_MODEL = 'risk_model'
     SUBDIVISION = 'subdivision'
+    DATASET = 'dataset'
 
 
 @dataclass
@@ -79,7 +83,8 @@ class Entity(metaclass=ABCMeta):
         EntityType.SUBDIVISION: 'countries/subdivisions',
         EntityType.KPI: 'kpis',
         EntityType.PORTFOLIO: 'portfolios',
-        EntityType.RISK_MODEL: 'risk/models'
+        EntityType.RISK_MODEL: 'risk/models',
+        EntityType.DATASET: 'data/datasets'
     }
 
     def __init__(self,
@@ -339,6 +344,15 @@ class PositionedEntity(metaclass=ABCMeta):
     def positioned_entity_type(self) -> EntityType:
         return self.__entity_type
 
+    def get_entitlements(self) -> Entitlements:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            response = GsPortfolioApi.get_portfolio(self.id)
+        elif self.positioned_entity_type == EntityType.ASSET:
+            response = GsAssetApi.get_asset(self.id)
+        else:
+            raise NotImplementedError
+        return Entitlements.from_target(response.entitlements)
+
     def get_latest_position_set(self,
                                 position_type: PositionType = PositionType.CLOSE) -> PositionSet:
         if self.positioned_entity_type == EntityType.ASSET:
@@ -378,22 +392,69 @@ class PositionedEntity(metaclass=ABCMeta):
         raise NotImplementedError
 
     def update_positions(self,
-                         position_sets: List[PositionSet]):
+                         position_sets: List[PositionSet],
+                         net_positions: bool = True):
         if self.positioned_entity_type == EntityType.PORTFOLIO:
             if not position_sets:
                 return
-            GsPortfolioApi.update_positions(portfolio_id=self.id, position_sets=[p.to_target() for p in position_sets])
+            currency = GsPortfolioApi.get_portfolio(self.id).currency
+            new_sets = []
+            for pos_set in position_sets:
+                if pos_set.reference_notional is None:
+                    incorrect_set = any([pos.quantity is None or pos.weight is not None for pos in pos_set.positions])
+                    if incorrect_set:
+                        raise MqValueError('If you would like to upload position sets without notionals, '
+                                           'every position must have a quantity and cannot have a weight.')
+                    new_sets.append(pos_set)
+                else:
+                    new_sets.append(self._convert_pos_set_with_weights(pos_set, currency))
+            GsPortfolioApi.update_positions(portfolio_id=self.id, position_sets=[p.to_target() for p in new_sets])
             time.sleep(3)
         else:
             raise NotImplementedError
 
+    @staticmethod
+    def _convert_pos_set_with_weights(position_set: PositionSet, currency: Currency) -> PositionSet:
+        positions_to_price = []
+        for position in position_set.positions:
+            if position.weight is None:
+                raise MqValueError('If you are uploading a position set with a notional value, every position in that '
+                                   'set must have a weight')
+            if position.quantity is not None:
+                raise MqValueError('If you are uploading a position set with a notional value, no position in that '
+                                   'set can have a quantity')
+            positions_to_price.append({
+                'assetId': position.asset_id,
+                'weight': position.weight
+            })
+        payload = {
+            'positions': positions_to_price,
+            'parameters': {
+                'targetNotional': position_set.reference_notional,
+                'currency': currency.value,
+                'pricingDate': position_set.date.strftime('%Y-%m-%d'),
+                'assetDataSetId': 'GSEOD',
+                'notionalType': 'Gross'
+            }
+        }
+        try:
+            price_results = GsSession.current._post('/price/positions', payload)
+        except Exception as e:
+            raise MqValueError('There was an error pricing your positions. Please try uploading your positions as '
+                               f'quantities instead: {e}')
+        positions = [Position(identifier=p['assetId'],
+                              asset_id=p['assetId'],
+                              quantity=p['quantity']) for p in price_results['positions']]
+        return PositionSet(date=position_set.date,
+                           positions=positions)
+
     def get_positions_data(self,
                            start: dt.date = DateLimit.LOW_LIMIT.value,
                            end: dt.date = dt.date.today(),
                            fields: [str] = None,
                            position_type: PositionType = PositionType.CLOSE) -> List[Dict]:
         if self.positioned_entity_type == EntityType.ASSET:
-            return GsAssetApi.get_asset_positions_data(self.id, start, end, fields, position_type)
+            return GsIndexApi.get_positions_data(self.id, start, end, fields, position_type)
         if self.positioned_entity_type == EntityType.PORTFOLIO:
             return GsPortfolioApi.get_positions_data(self.id, start, end, fields, position_type)
         raise NotImplementedError
@@ -475,7 +536,7 @@ class PositionedEntity(metaclass=ABCMeta):
                           'function parameters.')
         return reports[0]
 
-    def get_thematic_report(self) -> List[ThematicReport]:
+    def get_thematic_report(self) -> ThematicReport:
         if self.positioned_entity_type in [EntityType.PORTFOLIO, EntityType.ASSET]:
             position_source_type = self.positioned_entity_type.value.capitalize()
             reports = GsReportApi.get_reports(limit=100,
@@ -520,8 +581,16 @@ class PositionedEntity(metaclass=ABCMeta):
     def get_all_esg_data(self,
                          measures: List[ESGMeasure] = None,
                          cards: List[ESGCard] = None,
-                         pricing_date: dt.date = business_day_offset(dt.date.today(), -1, roll='forward'),
+                         pricing_date: dt.date = None,
                          benchmark_id: str = None) -> Dict:
+        """
+        Get all ESG Data
+        :param measures: list of ESG Measures to include in results
+        :param cards: list of ESG Cards to include in results
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :param benchmark_id: optional benchmark asset ID to include in results
+        :return: a dictionary of results
+        """
         return GsEsgApi.get_esg(entity_id=self.id,
                                 pricing_date=pricing_date,
                                 cards=cards if cards else [c for c in ESGCard],
@@ -529,8 +598,7 @@ class PositionedEntity(metaclass=ABCMeta):
                                 benchmark_id=benchmark_id)
 
     def get_esg_summary(self,
-                        pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                    roll='forward')) -> pd.DataFrame:
+                        pricing_date: dt.date = None) -> pd.DataFrame:
         summary_data = GsEsgApi.get_esg(entity_id=self.id,
                                         pricing_date=pricing_date,
                                         cards=[ESGCard.SUMMARY]).get('summary')
@@ -538,8 +606,13 @@ class PositionedEntity(metaclass=ABCMeta):
 
     def get_esg_quintiles(self,
                           measure: ESGMeasure,
-                          pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                      roll='forward')) -> pd.DataFrame:
+                          pricing_date: dt.date = None) -> pd.DataFrame:
+        """
+        Get breakdown of entity by weight in each percentile quintile for requested ESG measure
+        :param measure: ESG Measure
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :return: a Pandas DataFrame with results
+        """
         quintile_data = GsEsgApi.get_esg(entity_id=self.id,
                                          pricing_date=pricing_date,
                                          cards=[ESGCard.QUINTILES],
@@ -550,32 +623,52 @@ class PositionedEntity(metaclass=ABCMeta):
 
     def get_esg_by_sector(self,
                           measure: ESGMeasure,
-                          pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                      roll='forward')) -> pd.DataFrame:
+                          pricing_date: dt.date = None) -> pd.DataFrame:
+        """
+        Get breakdown of entity by sector, along with the weighted average score of the compositions in each sector
+        :param measure: ESG Measure
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :return: a Pandas DataFrame with results
+        """
         return self._get_esg_breakdown(ESGCard.MEASURES_BY_SECTOR, measure, pricing_date)
 
     def get_esg_by_region(self,
                           measure: ESGMeasure,
-                          pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                      roll='forward')) -> pd.DataFrame:
+                          pricing_date: dt.date = None) -> pd.DataFrame:
+        """
+        Get breakdown of entity by region, along with the weighted average score of the compositions in each region
+        :param measure: ESG Measure
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :return: a Pandas DataFrame with results
+        """
         return self._get_esg_breakdown(ESGCard.MEASURES_BY_REGION, measure, pricing_date)
 
     def get_esg_top_ten(self,
                         measure: ESGMeasure,
-                        pricing_date: dt.date = business_day_offset(dt.date.today(), -1, roll='forward')):
+                        pricing_date: dt.date = None):
+        """
+        Get entity constituents with the ten highest ESG percentile values
+        :param measure: ESG Measure
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :return: a Pandas DataFrame with results
+        """
         return self._get_esg_ranked_card(ESGCard.TOP_TEN_RANKED, measure, pricing_date)
 
     def get_esg_bottom_ten(self,
                            measure: ESGMeasure,
-                           pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                       roll='forward')) -> pd.DataFrame:
+                           pricing_date: dt.date = None) -> pd.DataFrame:
+        """
+        Get entity constituents with the ten lowest ESG percentile values
+        :param measure: ESG Measure
+        :param pricing_date: optional pricing date; defaults to last previous business day
+        :return: a Pandas DataFrame with results
+        """
         return self._get_esg_ranked_card(ESGCard.BOTTOM_TEN_RANKED, measure, pricing_date)
 
     def _get_esg_ranked_card(self,
                              card: ESGCard,
                              measure: ESGMeasure,
-                             pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                         roll='forward')) -> pd.DataFrame:
+                             pricing_date: dt.date = None) -> pd.DataFrame:
         data = GsEsgApi.get_esg(entity_id=self.id,
                                 pricing_date=pricing_date,
                                 cards=[card],
@@ -586,8 +679,7 @@ class PositionedEntity(metaclass=ABCMeta):
     def _get_esg_breakdown(self,
                            card: ESGCard,
                            measure: ESGMeasure,
-                           pricing_date: dt.date = business_day_offset(dt.date.today(), -1,
-                                                                       roll='forward')) -> pd.DataFrame:
+                           pricing_date: dt.date = None) -> pd.DataFrame:
         sector_data = GsEsgApi.get_esg(entity_id=self.id,
                                        pricing_date=pricing_date,
                                        cards=[card],
@@ -602,7 +694,8 @@ class PositionedEntity(metaclass=ABCMeta):
                              include_estimates: bool = False,
                              use_historical_data: bool = False,
                              normalize_emissions: bool = False,
-                             cards: List[CarbonCard] = [c for c in CarbonCard]) -> Dict:
+                             cards: List[CarbonCard] = [c for c in CarbonCard],
+                             analytics_view: CarbonAnalyticsView = CarbonAnalyticsView.LONG) -> Dict:
         return GsCarbonApi.get_carbon_analytics(entity_id=self.id,
                                                 benchmark_id=benchmark_id,
                                                 reporting_year=reporting_year,
@@ -610,32 +703,37 @@ class PositionedEntity(metaclass=ABCMeta):
                                                 include_estimates=include_estimates,
                                                 use_historical_data=use_historical_data,
                                                 normalize_emissions=normalize_emissions,
-                                                cards=cards)
+                                                cards=cards,
+                                                analytics_view=analytics_view)
 
     def get_carbon_coverage(self,
                             reporting_year: str = 'Latest',
                             include_estimates: bool = False,
                             use_historical_data: bool = False,
-                            coverage_type: CarbonCoverageCategory =
-                            CarbonCoverageCategory.WEIGHTS) -> pd.DataFrame:
+                            coverage_category: CarbonCoverageCategory = CarbonCoverageCategory.WEIGHTS,
+                            analytics_view: CarbonAnalyticsView = CarbonAnalyticsView.LONG) -> pd.DataFrame:
         coverage = self.get_carbon_analytics(reporting_year=reporting_year,
                                              include_estimates=include_estimates,
                                              use_historical_data=use_historical_data,
-                                             cards=[CarbonCard.COVERAGE]).get(CarbonCard.COVERAGE.value).get(
-            coverage_type.value, {}).get(CarbonEntityType.PORTFOLIO.value, {})
+                                             cards=[CarbonCard.COVERAGE],
+                                             analytics_view=analytics_view).get(CarbonCard.COVERAGE.value).get(
+            coverage_category.value, {}).get(CarbonEntityType.PORTFOLIO.value, {})
         return pd.DataFrame(coverage)
 
     def get_carbon_sbti_netzero_coverage(self,
                                          reporting_year: str = 'Latest',
                                          include_estimates: bool = False,
                                          use_historical_data: bool = False,
-                                         coverage_type: CarbonTargetCoverageCategory =
-                                         CarbonTargetCoverageCategory.PORTFOLIO_EMISSIONS) -> pd.DataFrame:
+                                         target_coverage_category: CarbonTargetCoverageCategory =
+                                         CarbonTargetCoverageCategory.PORTFOLIO_EMISSIONS,
+                                         analytics_view: CarbonAnalyticsView =
+                                         CarbonAnalyticsView.LONG) -> pd.DataFrame:
         coverage = self.get_carbon_analytics(reporting_year=reporting_year,
                                              include_estimates=include_estimates,
                                              use_historical_data=use_historical_data,
-                                             cards=[CarbonCard.SBTI_AND_NET_ZERO_TARGETS]).get(
-            CarbonCard.SBTI_AND_NET_ZERO_TARGETS.value).get(coverage_type.value, {})
+                                             cards=[CarbonCard.SBTI_AND_NET_ZERO_TARGETS],
+                                             analytics_view=analytics_view).get(
+            CarbonCard.SBTI_AND_NET_ZERO_TARGETS.value).get(target_coverage_category.value, {})
         coverage = {target: target_coverage.get(CarbonEntityType.PORTFOLIO.value, {}) for target, target_coverage in
                     coverage.items()}
         return pd.DataFrame(coverage)
@@ -645,12 +743,14 @@ class PositionedEntity(metaclass=ABCMeta):
                              include_estimates: bool = False,
                              use_historical_data: bool = False,
                              normalize_emissions: bool = False,
-                             scope: CarbonScope = CarbonScope.TOTAL_GHG) -> pd.DataFrame:
+                             scope: CarbonScope = CarbonScope.TOTAL_GHG,
+                             analytics_view: CarbonAnalyticsView = CarbonAnalyticsView.LONG) -> pd.DataFrame:
         emissions = self.get_carbon_analytics(currency=currency,
                                               include_estimates=include_estimates,
                                               use_historical_data=use_historical_data,
                                               normalize_emissions=normalize_emissions,
-                                              cards=[CarbonCard.EMISSIONS]).get(CarbonCard.EMISSIONS.value).get(
+                                              cards=[CarbonCard.EMISSIONS],
+                                              analytics_view=analytics_view).get(CarbonCard.EMISSIONS.value).get(
             scope.value, {}).get(CarbonEntityType.PORTFOLIO.value, [])
         return pd.DataFrame(emissions)
 
@@ -662,13 +762,15 @@ class PositionedEntity(metaclass=ABCMeta):
                                         normalize_emissions: bool = False,
                                         scope: CarbonScope = CarbonScope.TOTAL_GHG,
                                         classification: CarbonEmissionsAllocationCategory =
-                                        CarbonEmissionsAllocationCategory.GICS_SECTOR) -> pd.DataFrame:
+                                        CarbonEmissionsAllocationCategory.GICS_SECTOR,
+                                        analytics_view: CarbonAnalyticsView = CarbonAnalyticsView.LONG) -> pd.DataFrame:
         allocation = self.get_carbon_analytics(reporting_year=reporting_year,
                                                currency=currency,
                                                include_estimates=include_estimates,
                                                use_historical_data=use_historical_data,
                                                normalize_emissions=normalize_emissions,
-                                               cards=[CarbonCard.ALLOCATIONS]).get(CarbonCard.ALLOCATIONS.value).get(
+                                               cards=[CarbonCard.ALLOCATIONS],
+                                               analytics_view=analytics_view).get(CarbonCard.ALLOCATIONS.value).get(
             scope.value, {}).get(CarbonEntityType.PORTFOLIO.value, {}).get(classification.value)
         return pd.DataFrame(allocation).rename(columns={'name': classification.value})
 
@@ -680,13 +782,15 @@ class PositionedEntity(metaclass=ABCMeta):
                                      use_historical_data: bool = False,
                                      scope: CarbonScope = CarbonScope.TOTAL_GHG,
                                      intensity_metric: CarbonEmissionsIntensityType =
-                                     CarbonEmissionsIntensityType.EI_ENTERPRISE_VALUE) -> pd.DataFrame:
+                                     CarbonEmissionsIntensityType.EI_ENTERPRISE_VALUE,
+                                     analytics_view: CarbonAnalyticsView = CarbonAnalyticsView.LONG) -> pd.DataFrame:
         attribution = self.get_carbon_analytics(benchmark_id=benchmark_id,
                                                 reporting_year=reporting_year,
                                                 currency=currency,
                                                 include_estimates=include_estimates,
                                                 use_historical_data=use_historical_data,
-                                                cards=[CarbonCard.ATTRIBUTION]).get(CarbonCard.ATTRIBUTION.value).get(
+                                                cards=[CarbonCard.ATTRIBUTION],
+                                                analytics_view=analytics_view).get(CarbonCard.ATTRIBUTION.value).get(
             scope.value, [])
         attribution_table = []
         for entry in attribution:
@@ -720,7 +824,8 @@ class PositionedEntity(metaclass=ABCMeta):
         for r in response:
             df.append({'date': r['date'], 'assetId': r['assetId'], 'basketId': r['basketId'],
                        'thematicExposure': r['beta'] * notional})
-        return pd.DataFrame(df)
+        df = pd.DataFrame(df)
+        return df.set_index('date')
 
     def get_thematic_beta(self,
                           basket_identifier: str,
@@ -741,4 +846,64 @@ class PositionedEntity(metaclass=ABCMeta):
         for r in response:
             df.append({'date': r['date'], 'assetId': r['assetId'], 'basketId': r['basketId'],
                        'thematicBeta': r['beta']})
-        return pd.DataFrame(df)
+        df = pd.DataFrame(df)
+        return df.set_index('date')
+
+    def get_all_thematic_exposures(self,
+                                   start_date: dt.date = None,
+                                   end_date: dt.date = None,
+                                   basket_ids: List[str] = None,
+                                   regions: List[Region] = None) -> pd.DataFrame:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            raise NotImplementedError
+        results = GsThematicApi.get_thematics(entity_id=self.id,
+                                              start_date=start_date,
+                                              end_date=end_date,
+                                              basket_ids=basket_ids,
+                                              regions=regions,
+                                              measures=[ThematicMeasure.ALL_THEMATIC_EXPOSURES])
+        return flatten_results_into_df(results)
+
+    def get_top_five_thematic_exposures(self,
+                                        start_date: dt.date = None,
+                                        end_date: dt.date = None,
+                                        basket_ids: List[str] = None,
+                                        regions: List[Region] = None) -> pd.DataFrame:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            raise NotImplementedError
+        results = GsThematicApi.get_thematics(entity_id=self.id,
+                                              start_date=start_date,
+                                              end_date=end_date,
+                                              basket_ids=basket_ids,
+                                              regions=regions,
+                                              measures=[ThematicMeasure.TOP_FIVE_THEMATIC_EXPOSURES])
+        return flatten_results_into_df(results)
+
+    def get_bottom_five_thematic_exposures(self,
+                                           start_date: dt.date = None,
+                                           end_date: dt.date = None,
+                                           basket_ids: List[str] = None,
+                                           regions: List[Region] = None) -> pd.DataFrame:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            raise NotImplementedError
+        results = GsThematicApi.get_thematics(entity_id=self.id,
+                                              start_date=start_date,
+                                              end_date=end_date,
+                                              basket_ids=basket_ids,
+                                              regions=regions,
+                                              measures=[ThematicMeasure.BOTTOM_FIVE_THEMATIC_EXPOSURES])
+        return flatten_results_into_df(results)
+
+    def get_thematic_breakdown(self,
+                               date: dt.date,
+                               basket_id: str) -> pd.DataFrame:
+        """
+        Get a by-asset breakdown of a portfolio or basket's thematic exposure to a particular flagship basket on a
+        particular date
+        :param date: date
+        :param basket_id: GS flagship basket's unique Marquee ID
+        :return: a Pandas DataFrame with results
+        """
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            raise NotImplementedError
+        return get_thematic_breakdown_as_df(entity_id=self.id, date=date, basket_id=basket_id)
