@@ -718,7 +718,7 @@ class Basket(Asset, PositionedEntity):
     @_validate(ErrorMessage.NON_ADMIN)
     def name(self, value: str):
         if len(value) > 24:
-            raise MqValueError(f'Basket name of {len(value)} characters is too long (must be <= 24 characters).')
+            _logger.info(f'Basket name of {len(value)} characters is too long (must be <= 24 characters).')
         self.__name = value
 
     @property
