@@ -28,11 +28,11 @@ from typing import Optional, Union
 from tqdm import tqdm
 
 from gs_quant.base import InstrumentBase, RiskKey, Scenario, get_enum_value
-from gs_quant.common import PricingLocation
-from gs_quant.context_base import ContextBaseWithDefault, nullcontext
+from gs_quant.common import PricingLocation, RiskMeasure
+from gs_quant.context_base import ContextBaseWithDefault
 from gs_quant.datetime.date import business_day_offset
 from gs_quant.risk import CompositeScenario, DataFrameWithInfo, ErrorValue, FloatWithInfo, MarketDataScenario, \
-    RiskMeasure, StringWithInfo
+    StringWithInfo
 from gs_quant.risk.results import PricingFuture
 from gs_quant.session import GsSession
 from gs_quant.target.common import PricingDateAndMarketDataAsOf
@@ -135,11 +135,10 @@ class PricingContext(ContextBaseWithDefault):
                 get_enum_value(PricingLocation, market_data_location):
             raise ValueError('market.location and market_data_location cannot be different')
 
-        if pricing_date:
-            if pricing_date > dt.date.today():
-                raise ValueError(
-                    'The PricingContext does not support a pricing_date in the future. Please use the RollFwd Scenario '
-                    'to roll the pricing_date to a future date')
+        if not market and pricing_date and pricing_date > dt.date.today():
+            raise ValueError(
+                'The PricingContext does not support a pricing_date in the future. Please use the RollFwd Scenario '
+                'to roll the pricing_date to a future date')
 
         if market:
             market_date = None
@@ -214,9 +213,11 @@ class PricingContext(ContextBaseWithDefault):
                         if self.__use_cache:
                             PricingCache.put(risk_key_, priceable_, result)
 
-            while self.__pending:
-                (risk_key_, _), future = self.__pending.popitem()
-                future.set_result(ErrorValue(risk_key_, 'No result returned'))
+            if not self.__is_async:
+                # In async mode we can't tell if we've completed, we could be re-used
+                while self.__pending:
+                    (risk_key_, _), future = self.__pending.popitem()
+                    future.set_result(ErrorValue(risk_key_, 'No result returned'))
 
         # Group requests optimally
         requests_by_provider = {}
@@ -252,7 +253,8 @@ class PricingContext(ContextBaseWithDefault):
                                             zip_longest(*[iter(dates_markets)] * (
                                                     1 if self._max_concurrent == 1000 else self._max_concurrent))]:
                             requests.append(RiskRequest(
-                                tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in insts_chunk),
+                                tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity,
+                                                   instrument_name=i.name) for i in insts_chunk),
                                 risk_measures,
                                 parameters=params,
                                 wait_for_results=not self.__is_batch,
