@@ -13,27 +13,28 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-import copy
 import datetime as dt
 import logging
 from itertools import chain
 from typing import Iterable, Optional, Tuple, Union
+from urllib.parse import quote
 
 import deprecation
 import numpy as np
 import pandas as pd
-from more_itertools import unique_everseen
-
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.portfolios import GsPortfolioApi
+from gs_quant.base import InstrumentBase
+from gs_quant.common import RiskMeasure
 from gs_quant.instrument import Instrument
 from gs_quant.markets import HistoricalPricingContext, OverlayMarket, PricingContext, PositionContext
 from gs_quant.priceable import PriceableImpl
-from gs_quant.risk import RiskMeasure, ResolvedInstrumentValues
+from gs_quant.risk import ResolvedInstrumentValues
 from gs_quant.risk.results import CompositeResultFuture, PortfolioRiskResult, PortfolioPath, PricingFuture
 from gs_quant.target.common import RiskPosition
 from gs_quant.target.portfolios import Portfolio as MarqueePortfolio
 from gs_quant.target.portfolios import Position, PositionSet, RiskRequest, PricingDateAndMarketDataAsOf
+from more_itertools import unique_everseen
 
 _logger = logging.getLogger(__name__)
 
@@ -66,6 +67,7 @@ class Portfolio(PriceableImpl):
 
         self.__name = name
         self.__id = None
+        self.__quote_id = None
 
     def __getitem__(self, item):
         if isinstance(item, (int, slice)):
@@ -127,6 +129,10 @@ class Portfolio(PriceableImpl):
     def id(self) -> str:
         return self.__id
 
+    @property
+    def quote_id(self) -> str:
+        return self.__quote_id
+
     @property
     def name(self) -> str:
         return self.__name
@@ -191,17 +197,17 @@ class Portfolio(PriceableImpl):
             return Portfolio(tuple(self[p] for p in paths_tuple), name=name)
 
     @staticmethod
-    def __from_internal_positions(id_type: str, positions_id):
-        instruments = GsPortfolioApi.get_instruments_by_position_type(id_type, positions_id)
+    def __from_internal_positions(id_type: str, positions_id, activity_type: str):
+        instruments = GsPortfolioApi.get_instruments_by_position_type(id_type, positions_id, activity_type)
         return Portfolio(instruments, name=positions_id)
 
     @staticmethod
     def from_eti(eti: str):
-        return Portfolio.__from_internal_positions('ETI', eti.replace(',', '%2C'))
+        return Portfolio.__from_internal_positions('ETI', quote(eti, safe=''), 'trade')
 
     @staticmethod
-    def from_book(book: str, book_type: str = 'risk'):
-        return Portfolio.__from_internal_positions(book_type, book)
+    def from_book(book: str, book_type: str = 'risk', activity_type: str = 'position'):
+        return Portfolio.__from_internal_positions(book_type, book, activity_type)
 
     @staticmethod
     def from_asset_id(asset_id: str, date=None):
@@ -251,7 +257,9 @@ class Portfolio(PriceableImpl):
     @staticmethod
     def from_quote(quote_id: str):
         instruments = GsPortfolioApi.get_instruments_by_workflow_id(quote_id)
-        return Portfolio(instruments, name=quote_id)
+        ret = Portfolio(instruments, name=quote_id)
+        ret.__quote_id = quote_id
+        return ret
 
     def save(self, overwrite: Optional[bool] = False):
         if self.portfolios:
@@ -273,40 +281,37 @@ class Portfolio(PriceableImpl):
         if len(position_set.positions) > 0:
             GsPortfolioApi.update_positions(self.__id, [position_set])
 
-    def save_as_quote(self, overwrite: Optional[bool] = False):
+    def save_as_quote(self, overwrite: Optional[bool] = False) -> str:
         if self.portfolios:
             raise ValueError('Cannot save portfolios with nested portfolios')
 
-        pricing_context = self._pricing_context
-
         request = RiskRequest(
             tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in self.instruments),
             (ResolvedInstrumentValues,),
-            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=pricing_context.pricing_date,
-                                                                        market=pricing_context.market),)
+            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=self._pricing_context.pricing_date,
+                                                                        market=self._pricing_context.market),)
         )
 
-        if self.__id:
+        if self.__quote_id:
             if not overwrite:
-                raise ValueError(f'Quote with id {id} already exists. Use overwrite=True to overwrite')
+                raise ValueError(f'Quote with id {self.__quote_id} already exists. Use overwrite=True to overwrite')
             else:
-                GsPortfolioApi.update_quote(self.__id, request)
-                _logger.info(f'Updated Structuring with id {self.__id}')
+                GsPortfolioApi.update_quote(self.__quote_id, request)
+                _logger.info(f'Updated quote with id {self.__quote_id}')
         else:
-            self.__id = GsPortfolioApi.save_quote(request)
-            _logger.info(f'Created Structuring with id {self.__id}')
+            self.__quote_id = GsPortfolioApi.save_quote(request)
+            _logger.info(f'Created quote with id {self.__quote_id}')
+        return self.__quote_id
 
     def save_to_shadowbook(self, name: str):
         if self.portfolios:
             raise ValueError('Cannot save portfolios with nested portfolios')
 
-        pricing_context = self._pricing_context
-
         request = RiskRequest(
             tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in self.instruments),
             (ResolvedInstrumentValues,),
-            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=pricing_context.pricing_date,
-                                                                        market=pricing_context.market),)
+            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=self._pricing_context.pricing_date,
+                                                                        market=self._pricing_context.market),)
         )
         status = GsPortfolioApi.save_to_shadowbook(request, name)
         print(f'Save to shadowbook status - {status}')
@@ -362,6 +367,9 @@ class Portfolio(PriceableImpl):
         self.priceables = [inst for inst in self.instruments if inst != priceable]
         return priceable
 
+    def extend(self, portfolio: Iterable):
+        self.priceables += tuple([p for p in portfolio])
+
     def to_frame(self, mappings: Optional[dict] = None) -> pd.DataFrame:
         def to_records(portfolio: Portfolio) -> list:
             records = []
@@ -494,11 +502,10 @@ class Portfolio(PriceableImpl):
 
         def cb(future: CompositeResultFuture):
             def update_market_data(all_market_data, this_market_data):
-                for item in this_market_data:
-                    existing_value = all_market_data.setdefault(item.coordinate, item.value)
-                    if abs(existing_value - item.value) > 1e-6:
-                        raise ValueError(
-                            f'Conflicting values for {item.coordinate}: {existing_value} vs {item.value}')
+                for coordinate, value in this_market_data.items():
+                    existing_value = all_market_data.setdefault(coordinate, value)
+                    if abs(existing_value - value) > 1e-6:
+                        raise ValueError(f'Conflicting values for {coordinate}: {existing_value} vs {value}')
 
             results = [f.result() for f in future.futures]
             is_historical = isinstance(results[0], dict)
@@ -507,15 +514,15 @@ class Portfolio(PriceableImpl):
 
             for result in results:
                 if market_data is not None:
-                    update_market_data(market_data, result.market_data)
+                    update_market_data(market_data, result.base_market.market_data_dict)
                 else:
                     for market in result.values():
                         update_market_data(overlay_markets.setdefault(market.base_market, {}), market.market_data)
 
             if market_data:
-                ret = OverlayMarket(base_market=results[0].base_market, market_data=market_data)
+                ret = OverlayMarket(base_market=results[0].base_market.clone_with_market_data(market_data))
             else:
-                ret = {base_market.date: OverlayMarket(base_market=base_market, market_data=market_data)
+                ret = {base_market.date: OverlayMarket(base_market=base_market.clone_with_market_data(market_data))
                        for base_market, market_data in overlay_markets.items()}
 
             if result_future:
@@ -530,7 +537,7 @@ class Portfolio(PriceableImpl):
             # PortfolioRiskResult should hold a copy of the portfolio instead of a reference to the portfolio
             # this is to prevent the portfolio object within portfolioriskresult to hold a reference to the portfolio
             # object should it later be modified in place (eg: resolution)
-            return PortfolioRiskResult(copy.deepcopy(self),
+            return PortfolioRiskResult(self.clone(),
                                        (risk_measure,) if isinstance(risk_measure, RiskMeasure) else risk_measure,
                                        [p.calc(risk_measure, fn=fn) for p in priceables])
 
@@ -548,3 +555,10 @@ class Portfolio(PriceableImpl):
                 self.__priceables = instruments
             return instruments
         return self.__priceables if return_priceables else self.all_instruments
+
+    def clone(self):
+        portfolio_clone = Portfolio([p if isinstance(p, InstrumentBase) else p.clone() for p in self.__priceables],
+                                    name=self.name)
+        portfolio_clone.__id = self.__id
+        portfolio_clone.__quote_id = self.__quote_id
+        return portfolio_clone
