@@ -32,7 +32,7 @@ import pytz
 from dateutil.relativedelta import relativedelta
 
 from gs_quant.api.gs.assets import GsAsset, AssetParameters, \
-    AssetType as GsAssetType, Currency
+    AssetType as GsAssetType, Currency, GsIdType
 from gs_quant.api.utils import ThreadPoolManager
 from gs_quant.base import get_enum_value
 from gs_quant.common import DateLimit
@@ -230,6 +230,7 @@ class SecurityIdentifier(EntityIdentifier):
     GSS = "gss"
     PRIMEID = "primeId"
     BBG = "bbg"
+    ASSET_ID = "assetId"
 
 
 class ReturnType(Enum):
@@ -511,21 +512,6 @@ class Asset(Entity, metaclass=ABCMeta):
         df = pd.DataFrame({'high': results[0], 'low': results[1], 'open': results[2], 'close': results[3]})
         return df.dropna()
 
-    def get_thematic_exposure(self,
-                              basket_identifier: str,
-                              notional: int = None,
-                              start: dt.date = DateLimit.LOW_LIMIT.value,
-                              end: dt.date = dt.date.today()) -> pd.DataFrame:
-        """Timeseries of daily thematic exposure of asset to requested flagship basket (only composites currently)"""
-        pass
-
-    def get_thematic_beta(self,
-                          basket_identifier: str,
-                          start: dt.date = DateLimit.LOW_LIMIT.value,
-                          end: dt.date = dt.date.today()) -> pd.DataFrame:
-        """Timeseries of daily thematic beta of asset to requested flagship basket (only composites currently)"""
-        pass
-
     @abstractmethod
     def get_type(self) -> AssetType:
         """Overridden by sub-classes to return security type"""
@@ -1017,6 +1003,23 @@ class DefaultSwap(Asset):
         return AssetType.DEFAULT_SWAP
 
 
+class XccySwapMTM(Asset):
+    """XccySwapMTM
+
+    Represents a cross-currency mark-to-market swap.
+
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, AssetClass.Rates, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.XccySwapMTM
+
+
 class SecurityMasterSource(Enum):
     ASSET_SERVICE = auto()
     SECURITY_MASTER = auto()
@@ -1157,6 +1160,9 @@ class SecurityMaster:
         if asset_type == GsAssetType.Binary.value:
             return Binary(gs_asset.id, gs_asset.name, gs_asset.assetClass, entity=asset_entity)
 
+        if asset_type == GsAssetType.XccySwapMTM.value:
+            return XccySwapMTM(gs_asset.id, gs_asset.name, entity=asset_entity)
+
         raise TypeError(f'unsupported asset type {asset_type}')
 
     @classmethod
@@ -1369,7 +1375,8 @@ class SecurityMaster:
         params = {
             'fields': ['id', 'identifiers', 'assetClass', 'type'],
             'asOfDate': as_of.date(),
-            'limit': cls._page_size
+            'limit': cls._page_size,
+            'type': types
         }
 
         while True:
@@ -1378,10 +1385,13 @@ class SecurityMaster:
                 return
 
             output = {}
+
             for e in r['results']:
-                # TODO: perform filtering on server side
-                if (class_ is None or e['assetClass'] == class_.value) and (types is None or e['type'] in types):
+                # TODO: perform assetClass filtering on server side once assetClass is supported (just Equties is
+                #  supported for now)
+                if class_ is None or e['assetClass'] == class_.value:
                     box = e['identifiers']
+                    box['id'] = e['id']  # copy top-level security id into result
                     key = box[id_type.value]
                     if key in box:
                         _logger.debug(f'encountered duplicate key {key}')
@@ -1424,40 +1434,117 @@ class SecurityMaster:
                 return accumulator
 
     @classmethod
-    def map_identifiers(cls, ids: Iterable[str],
-                        to_identifiers: Iterable[SecurityIdentifier] = frozenset([SecurityIdentifier.GSID]),
-                        start_date: datetime.date = None, end_date: datetime.date = None) -> Dict[datetime.date, dict]:
+    def map_identifiers(
+            cls,
+            input_type: SecurityIdentifier,
+            ids: Iterable[str],
+            output_types: Iterable[SecurityIdentifier] = frozenset([SecurityIdentifier.GSID]),
+            start_date: datetime.date = None,
+            end_date: datetime.date = None,
+            as_of_date: datetime.date = None
+    ) -> Dict[datetime.date, dict]:
         """
-        Map to (other) identifiers from given IDs.
+        Map to other identifier types, from given IDs.
 
-        :param ids: security IDs e.g. GSIDs or BBIDs
-        :param to_identifiers: types of IDs to map to
-        :param start_date: start of date range
-        :param end_date: end of date range
-        :return: dict containing mappings for each date in range
+        :param input_type: type of input IDs
+        :param ids: security IDs
+        :param output_types: types of IDs to map to
+        :param start_date: first as-of date (defaults to current date)
+        :param end_date: last as-of date (defaults to current date)
+        :param as_of_date: an exact as-of date for mapping
+        :return: dict containing mappings for as-of date(s)
 
         **Examples**
 
         Get CUSIP for GS UN:
-        >>> result = SecurityMaster.map_identifiers(["GS UN"], [SecurityIdentifier.CUSIP])
+        >>> result = SecurityMaster.map_identifiers(SecurityIdentifier.BBID, ["GS UN"], [SecurityIdentifier.CUSIP])
 
-        Get Bloomberg ticker for 104563 over a range of dates:
-        >>> result = SecurityMaster.map_identifiers(["104563"], [SecurityIdentifier.BBG],
-        ...                                         datetime.date(2021, 4, 16), datetime.date(2021, 4, 19))
+        Get Bloomberg ticker for 104563 as-of a past date:
+        >>> result = SecurityMaster.map_identifiers(SecurityIdentifier.GSID, ["104563"], [SecurityIdentifier.BBG],
+        ...                                         as_of_date=datetime.date(2021, 4, 19))
         """
-        if cls._source != SecurityMasterSource.SECURITY_MASTER:
-            raise NotImplementedError("method not available when using Asset Service")
-
         if isinstance(ids, str):
-            raise MqTypeError("expected an iterable of strings e.g. a list of strings")
+            raise MqTypeError("expected an iterable of strings e.g. list of strings")
 
+        def get_asset_id_type(type_: SecurityIdentifier):
+            try:
+                return GsIdType[type_.value]
+            except KeyError:
+                raise MqValueError(f'unsupported type {type_.value}')
+
+        if cls._source == SecurityMasterSource.ASSET_SERVICE:
+            output_types = list(output_types)
+            if len(output_types) != 1:
+                raise MqValueError('provide exactly one output type')
+            if (start_date or end_date) is not None:
+                raise MqValueError('use as_of_date instead of start_date and/or end_date')
+
+            input_type = get_asset_id_type(input_type)
+            output_type = get_asset_id_type(output_types[0])
+            as_of = None if as_of_date is None else datetime.datetime.combine(as_of_date,
+                                                                              datetime.time(tzinfo=pytz.UTC))
+            result = GsAssetApi.map_identifiers(input_type, output_type, list(ids), as_of=as_of, multimap=True)
+            if len(result) == 0:
+                return result
+            inner = {k: {output_type.name: v} for k, v in result.items()}
+            return {as_of.strftime('%Y-%m-%d'): inner}
+
+        assert cls._source == SecurityMasterSource.SECURITY_MASTER
         params = {
             'identifiers': list(ids),
-            'toIdentifiers': [identifier.value for identifier in to_identifiers]
+            'toIdentifiers': [identifier.value for identifier in output_types],
+            'compact': True
         }
+        if as_of_date is not None:
+            if (start_date or end_date) is not None:
+                raise MqValueError('provide (start date / end date) or as-of date, but not both')
+            params['startDate'] = as_of_date
+            params['endDate'] = as_of_date
+
         if start_date is not None:
             params['startDate'] = start_date
         if end_date is not None:
             params['endDate'] = end_date
         r = _get_with_retries('/markets/securities/map', params)
-        return r['results']
+        # TODO: pass input_type along (after updating endpoint implementation)
+
+        results = r['results']
+        if isinstance(results, dict):
+            return results
+
+        output = dict()
+        date_format = '%Y-%m-%d'
+        date_delta = datetime.timedelta(days=1)
+        for row in results:
+            current = datetime.datetime.strptime(row['startDate'], date_format)
+            end = datetime.datetime.strptime(row['endDate'], date_format)
+            while current <= end:
+                outer = output.setdefault(current, dict())
+                inner = outer.setdefault(row["input"], dict())
+                output_type = row["outputType"]
+                output_value = row["outputValue"]
+                if output_type == "ric":
+                    if SecurityIdentifier.RIC in output_types:
+                        values = inner.setdefault('ric', [])
+                        if output_value not in values:
+                            values.append(output_value)
+                    if SecurityIdentifier.ASSET_ID in output_types and "assetId" in row:
+                        values = inner.setdefault('assetId', [])
+                        asset_id = row['assetId']
+                        if asset_id not in values:
+                            values.append(asset_id)
+                elif output_type == "bbg":
+                    if SecurityIdentifier.BBG in output_types:
+                        inner[output_type] = output_value
+                    if SecurityIdentifier.BBID in output_types:
+                        inner[SecurityIdentifier.BBID.value] = f"{output_value} {row.get('exchange', '??')}"
+                    if SecurityIdentifier.BCID in output_types:
+                        inner[SecurityIdentifier.BCID.value] = f"{output_value} {row.get('compositeExchange', '??')}"
+                else:
+                    if SecurityIdentifier(output_type) in output_types:
+                        inner[output_type] = output_value
+
+                current += date_delta
+
+        # much faster to run strftime (once for each date) at the end
+        return {k.strftime(date_format): v for k, v in output.items()}
