@@ -364,10 +364,9 @@ class FactorRiskModel(RiskModel):
         :param factor_metadata: factor metadata object
         """
         try:
-            GsFactorRiskModelApi.get_risk_model_factor(self.id, factor_id=factor_metadata.identifier)
+            GsFactorRiskModelApi.update_risk_model_factor(self.id, factor_metadata)
         except MqRequestError:
             GsFactorRiskModelApi.create_risk_model_factor(self.id, factor_metadata)
-        GsFactorRiskModelApi.update_risk_model_factor(self.id, factor_metadata)
 
     def delete_factor_metadata(self, factor_id: str):
         """ Delete a factor's metadata from a risk model
@@ -784,7 +783,6 @@ class FactorRiskModel(RiskModel):
 
         data = risk_model_data_to_json(data) if type(data) == RiskModelData else data
         target_universe_size = get_universe_size(data)
-        print(target_universe_size)
         if target_universe_size > max_asset_batch_size:
             print('Batching uploads due to universe size')
             batch_and_upload_partial_data(self.id, data, max_asset_batch_size)
