@@ -357,7 +357,7 @@ def aggregate_risk(results: Iterable[Union[DataFrameWithInfo, Future]], threshol
     delta and vega are Dataframes, representing the merged risk of the individual instruments
     """
     dfs = [r.result().raw_value if isinstance(r, Future) else r.raw_value for r in results]
-    result = pd.concat(dfs)
+    result = pd.concat(dfs).fillna(0)
     result = result.groupby([c for c in result.columns if c != 'value'], as_index=False).sum()
 
     if threshold is not None:
