@@ -21,7 +21,8 @@ from gs_quant.base import InstrumentBase, RiskKey
 
 from .core import DataFrameWithInfo, ErrorValue, UnsupportedValue, FloatWithInfo, SeriesWithInfo, StringWithInfo, \
     sort_values
-from .measures import EqDelta, EqGamma, EqVega
+from gs_quant.target.measures import EqDelta, EqGamma, EqVega
+from gs_quant.risk.measures import PnlExplain
 
 _logger = logging.getLogger(__name__)
 __scalar_risk_measures = (EqDelta, EqGamma, EqVega)
@@ -52,6 +53,21 @@ def __dataframe_handler(result: Iterable, mappings: tuple, risk_key: RiskKey, re
     return df
 
 
+def __dataframe_handler_unsorted(result: Iterable, mappings: tuple, date_cols: tuple, risk_key: RiskKey,
+                                 request_id: Optional[str] = None) -> DataFrameWithInfo:
+    first_row = next(iter(result), None)
+    if first_row is None:
+        return DataFrameWithInfo(risk_key=risk_key, request_id=request_id)
+
+    records = ([row.get(field_from) for field_to, field_from in mappings] for row in result)
+    df = DataFrameWithInfo(records, risk_key=risk_key, request_id=request_id)
+    df.columns = [m[0] for m in mappings]
+    for dt_col in date_cols:
+        df[dt_col] = df[dt_col].map(lambda x: dt.datetime.strptime(x, '%Y-%m-%d').date() if isinstance(x, str) else x)
+
+    return df
+
+
 def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None) \
         -> DataFrameWithInfo:
     mappings = (
@@ -69,14 +85,8 @@ def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBa
         ('rate', 'rate'),
         ('discount_factor', 'discountFactor')
     )
-
-    for cashflow in result['cashflows']:
-        for field in ('payDate', 'setDate', 'accStart', 'accEnd'):
-            value = cashflow.get(field)
-            date = dt.datetime.strptime(value, '%Y-%m-%d').date() if value else dt.date.max
-            cashflow[field] = date
-
-    return __dataframe_handler(result['cashflows'], mappings, risk_key, request_id=request_id)
+    date_cols = ('payment_date', 'set_date', 'accrual_start_date', 'accrual_end_date')
+    return __dataframe_handler_unsorted(result['cashflows'], mappings, date_cols, risk_key, request_id=request_id)
 
 
 def error_handler(result: dict, risk_key: RiskKey, instrument: InstrumentBase, request_id: Optional[str] = None) \
@@ -95,8 +105,12 @@ def leg_definition_handler(result: dict, risk_key: RiskKey, instrument: Instrume
 
 
 def message_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None) \
-        -> StringWithInfo:
-    return StringWithInfo(risk_key, result.get('message'), request_id=request_id)
+        -> Union[StringWithInfo, ErrorValue]:
+    message = result.get('message')
+    if message is None:
+        return ErrorValue(risk_key, "No result returned", request_id=request_id)
+    else:
+        return StringWithInfo(risk_key, message, request_id=request_id)
 
 
 def number_and_unit_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
@@ -163,7 +177,10 @@ def risk_by_class_handler(result: dict, risk_key: RiskKey, _instrument: Instrume
             ('value', 'value')
         )
 
-        return __dataframe_handler(classes, mappings, risk_key, request_id=request_id)
+        if isinstance(risk_key.risk_measure, PnlExplain):
+            return __dataframe_handler_unsorted(classes, mappings, (), risk_key, request_id=request_id)
+        else:
+            return __dataframe_handler(classes, mappings, risk_key, request_id=request_id)
 
 
 def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
@@ -200,6 +217,37 @@ def fixing_table_handler(result: dict, risk_key: RiskKey, _instrument: Instrumen
     return SeriesWithInfo(values, index=dates, risk_key=risk_key, request_id=request_id)
 
 
+def canonical_projection_table_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                                       request_id: Optional[str] = None) -> DataFrameWithInfo:
+    mappings = (
+        ('asset_class', 'assetClass'),
+        ('asset', 'asset'),
+        ('asset_family', 'assetFamily'),
+        ('asset_sub_family', 'assetSubFamily'),
+        ('product', 'product'),
+        ('product_family', 'productFamily'),
+        ('product_sub_family', 'productSubFamily'),
+        ('side', 'side'),
+        ('size', 'size'),
+        ('size_unit', 'sizeUnit'),
+        ('quote_level', 'quoteLevel'),
+        ('quote_unit', 'quoteUnit'),
+        ('start_date', 'startDate'),
+        ('end_date', 'endDate'),
+        ('expiration_date', 'expiryDate'),
+        ('strike', 'strike'),
+        ('strike_unit', 'strikeUnit'),
+        ('option_type', 'optionType'),
+        ('option_style', 'optionStyle'),
+        ('tenor', 'tenor'),
+        ('tenor_unit', 'tenorUnit'),
+        ('premium_currency', 'premiumCcy'),
+        ('currency', 'currency')
+    )
+    date_cols = ('start_date', 'end_date', 'expiration_date')
+    return __dataframe_handler_unsorted(result['rows'], mappings, date_cols, risk_key, request_id)
+
+
 def risk_float_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                        request_id: Optional[str] = None) -> FloatWithInfo:
     return FloatWithInfo(risk_key, result['values'][0], request_id=request_id)
@@ -209,7 +257,8 @@ def mdapi_table_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
                         request_id: Optional[str] = None) -> DataFrameWithInfo:
     coordinates = []
     for r in result['rows']:
-        point = ';'.join(r['coordinate']['point']) if isinstance(r['coordinate']['point'], list) else ""
+        raw_point = r['coordinate'].get('point', '')
+        point = ';'.join(raw_point) if isinstance(raw_point, list) else raw_point
         r['coordinate'].update({'point': point})
         r['coordinate'].update({'value': r['value']})
         r['coordinate'].update({'permissions': r['permissions']})
@@ -226,6 +275,33 @@ def mdapi_table_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
     return __dataframe_handler(coordinates, mappings, risk_key, request_id=request_id)
 
 
+def mmapi_table_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                        request_id: Optional[str] = None) -> DataFrameWithInfo:
+    coordinates = []
+    for r in result['rows']:
+        raw_point = r['modelCoordinate'].get('point', '')
+        point = ';'.join(raw_point) if isinstance(raw_point, list) else raw_point
+        r['modelCoordinate'].update({'point': point})
+        raw_tags = r['modelCoordinate'].get('tags', '')
+        tags = ';'.join(raw_tags) if isinstance(raw_tags, list) else raw_tags
+        r['modelCoordinate'].update({'tags': tags})
+        rows = r['value'].get('value', '')
+        DataPoints = []
+        for row in rows:
+            DataPoints.append([dt.date.fromisoformat(row["date"]), row["value"]])
+        r['modelCoordinate'].update({'value': DataPoints})
+        coordinates.append(r['modelCoordinate'])
+
+    mappings = (('mkt_type', 'type'),
+                ('mkt_asset', 'asset'),
+                ('mkt_point', 'point'),
+                ('mkt_tags', 'tags'),
+                ('mkt_quoting_style', 'quotingStyle'),
+                ('value', 'value'))
+
+    return __dataframe_handler(coordinates, mappings, risk_key, request_id=request_id)
+
+
 def market_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                    request_id: Optional[str] = None) -> StringWithInfo:
     return StringWithInfo(risk_key, result.get('marketRef'), request_id=request_id)
@@ -242,12 +318,14 @@ result_handlers = {
     'LegDefinition': leg_definition_handler,
     'Message': message_handler,
     'MDAPITable': mdapi_table_handler,
+    'MMAPITable': mmapi_table_handler,
     'NumberAndUnit': number_and_unit_handler,
     'RequireAssets': required_assets_handler,
     'Risk': risk_handler,
     'RiskByClass': risk_by_class_handler,
     'RiskVector': risk_vector_handler,
     'FixingTable': fixing_table_handler,
+    'CanonicalProjectionTable': canonical_projection_table_handler,
     'RiskSecondOrderVector': risk_float_handler,
     'RiskTheta': risk_float_handler,
     'Market': market_handler,
