@@ -13,23 +13,24 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+
+
+from abc import abstractmethod
+import backoff
+import certifi
+from configparser import ConfigParser
+from enum import Enum, auto, unique
 import inspect
 import itertools
 import json
-import os
-import ssl
-from abc import abstractmethod
-from configparser import ConfigParser
-from enum import Enum, auto, unique
-from typing import Optional, Union, Iterable
-
-import backoff
-import certifi
 import msgpack
+import os
 import pandas as pd
 import requests
 import requests.adapters
 import requests.cookies
+import ssl
+from typing import Optional, Union, Iterable
 
 from gs_quant import version as APP_VERSION
 from gs_quant.base import Base
@@ -152,7 +153,7 @@ class GsSession(ContextBase):
             self,
             method: str,
             path: str,
-            payload: Optional[Union[dict, str, Base, pd.DataFrame]] = None,
+            payload: Optional[Union[dict, str, bytes, Base, pd.DataFrame]] = None,
             request_headers: Optional[dict] = None,
             cls: Optional[type] = None,
             try_auth: Optional[bool] = True,
@@ -184,7 +185,7 @@ class GsSession(ContextBase):
             kwargs['headers'] = headers
 
             if is_dataframe or payload:
-                kwargs['data'] = payload if isinstance(payload, str) else \
+                kwargs['data'] = payload if isinstance(payload, (str, bytes)) else \
                     msgpack.dumps(payload, default=default) if use_msgpack else json.dumps(payload, cls=JSONEncoder)
         else:
             raise MqError('not implemented')
@@ -237,7 +238,7 @@ class GsSession(ContextBase):
                               cls=cls, include_version=include_version, timeout=timeout,
                               return_request_id=return_request_id)
 
-    def _post(self, path: str, payload: Optional[Union[dict, Base, pd.DataFrame]] = None,
+    def _post(self, path: str, payload: Optional[Union[dict, bytes, Base, pd.DataFrame]] = None,
               request_headers: Optional[dict] = None, cls: Optional[type] = None,
               include_version: Optional[bool] = True, timeout: Optional[int] = DEFAULT_TIMEOUT,
               return_request_id: Optional[bool] = False) -> Union[Base, tuple, dict]:
@@ -345,7 +346,7 @@ class GsSession(ContextBase):
                     return PassThroughGSSSOSession(environment_or_domain, token, api_version=api_version,
                                                    application=application, http_adapter=http_adapter)
                 except NameError:
-                    raise MqUninitialisedError('This option requires gs_quant_internal to be installed')
+                    raise MqUninitialisedError('This option requires gs_quant_auth to be installed')
             else:
                 return PassThroughSession(environment_or_domain, token, api_version=api_version,
                                           application=application, http_adapter=http_adapter)
@@ -421,7 +422,7 @@ class PassThroughSession(GsSession):
 
 
 try:
-    from gs_quant_internal.kerberos.session_kerberos import KerberosSessionMixin
+    from gs_quant_auth.kerberos.session_kerberos import KerberosSessionMixin
 
     class KerberosSession(KerberosSessionMixin, GsSession):
 
