@@ -103,31 +103,6 @@ class ReportType(EnumBase, Enum):
     PCO = 'PCO'    
 
 
-class ParametersOverrides(Base):
-        
-    """Overriding parameters specific to the report type"""
-
-    @camel_case_translate
-    def __init__(
-        self,
-        csa_term: str = None,
-        name: str = None
-    ):        
-        super().__init__()
-        self.csa_term = csa_term
-        self.name = name
-
-    @property
-    def csa_term(self) -> str:
-        """The CSA Term for CSA specific discounting, e.g. EUR-1"""
-        return self.__csa_term
-
-    @csa_term.setter
-    def csa_term(self, value: str):
-        self._property_changed('csa_term')
-        self.__csa_term = value        
-
-
 class Report(Base):
         
     @camel_case_translate
@@ -401,6 +376,43 @@ class Report(Base):
         self.__percentage_complete = value        
 
 
+class ParametersOverrides(Base):
+        
+    """Overriding parameters specific to the report type"""
+
+    @camel_case_translate
+    def __init__(
+        self,
+        csa_term: str = None,
+        pricing_location: Union[PricingLocation, str] = None,
+        name: str = None
+    ):        
+        super().__init__()
+        self.csa_term = csa_term
+        self.pricing_location = pricing_location
+        self.name = name
+
+    @property
+    def csa_term(self) -> str:
+        """The CSA Term for CSA specific discounting, e.g. EUR-1"""
+        return self.__csa_term
+
+    @csa_term.setter
+    def csa_term(self, value: str):
+        self._property_changed('csa_term')
+        self.__csa_term = value        
+
+    @property
+    def pricing_location(self) -> Union[PricingLocation, str]:
+        """Based on the location of the exchange. Called 'Native Region' in SecDB"""
+        return self.__pricing_location
+
+    @pricing_location.setter
+    def pricing_location(self, value: Union[PricingLocation, str]):
+        self._property_changed('pricing_location')
+        self.__pricing_location = get_enum_value(PricingLocation, value)        
+
+
 class ReportGenerateRequest(Base):
         
     """Request body to synchronously generate a report file."""
@@ -592,7 +604,9 @@ class ReportBatchScheduleRequest(Base):
         self,
         reports: Tuple[str, ...] = None,
         reports_with_parameters_overrides: Tuple[ReportWithParametersOverrides, ...] = None,
+        time: datetime.datetime = None,
         end_date: datetime.date = None,
+        use_close_date: datetime.date = None,
         start_date: datetime.date = None,
         parameters: ReportParameters = None,
         priority: Union[ReportJobPriority, str] = None,
@@ -601,7 +615,9 @@ class ReportBatchScheduleRequest(Base):
         super().__init__()
         self.reports = reports
         self.reports_with_parameters_overrides = reports_with_parameters_overrides
+        self.time = time
         self.end_date = end_date
+        self.use_close_date = use_close_date
         self.start_date = start_date
         self.parameters = parameters
         self.priority = priority
@@ -627,6 +643,16 @@ class ReportBatchScheduleRequest(Base):
         self._property_changed('reports_with_parameters_overrides')
         self.__reports_with_parameters_overrides = value        
 
+    @property
+    def time(self) -> datetime.datetime:
+        """ISO 8601-formatted timestamp"""
+        return self.__time
+
+    @time.setter
+    def time(self, value: datetime.datetime):
+        self._property_changed('time')
+        self.__time = value        
+
     @property
     def end_date(self) -> datetime.date:
         """ISO 8601-formatted date"""
@@ -637,6 +663,16 @@ class ReportBatchScheduleRequest(Base):
         self._property_changed('end_date')
         self.__end_date = value        
 
+    @property
+    def use_close_date(self) -> datetime.date:
+        """ISO 8601-formatted date"""
+        return self.__use_close_date
+
+    @use_close_date.setter
+    def use_close_date(self, value: datetime.date):
+        self._property_changed('use_close_date')
+        self.__use_close_date = value        
+
     @property
     def start_date(self) -> datetime.date:
         """ISO 8601-formatted date"""
@@ -675,6 +711,8 @@ class ReportJob(Base):
         self,
         start_date: datetime.date = None,
         end_date: datetime.date = None,
+        time: datetime.datetime = None,
+        use_close_date: datetime.date = None,
         elapsed_time: float = None,
         percentage_complete: float = None,
         execution_time: datetime.datetime = None,
@@ -698,6 +736,8 @@ class ReportJob(Base):
         super().__init__()
         self.start_date = start_date
         self.end_date = end_date
+        self.time = time
+        self.use_close_date = use_close_date
         self.elapsed_time = elapsed_time
         self.percentage_complete = percentage_complete
         self.execution_time = execution_time
@@ -738,6 +778,26 @@ class ReportJob(Base):
         self._property_changed('end_date')
         self.__end_date = value        
 
+    @property
+    def time(self) -> datetime.datetime:
+        """ISO 8601-formatted timestamp"""
+        return self.__time
+
+    @time.setter
+    def time(self, value: datetime.datetime):
+        self._property_changed('time')
+        self.__time = value        
+
+    @property
+    def use_close_date(self) -> datetime.date:
+        """Force fixed close date for intraday risk calculations."""
+        return self.__use_close_date
+
+    @use_close_date.setter
+    def use_close_date(self, value: datetime.date):
+        self._property_changed('use_close_date')
+        self.__use_close_date = value        
+
     @property
     def elapsed_time(self) -> float:
         """Time taken to execute report (in milliseconds)"""
