@@ -17,7 +17,7 @@ import datetime as dt
 
 import pandas as pd
 import pytest
-from pandas.util.testing import assert_frame_equal, assert_series_equal
+from pandas.testing import assert_frame_equal, assert_series_equal
 
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.context_base import ContextMeta
