@@ -45,6 +45,16 @@ def test_pricing_context(mocker):
             _ = swap1.calc(risk.Price)
 
 
+def test_pricing_dates():
+    # May be on weekend but doesn't matter for basic test
+    future_date = dt.date.today() + dt.timedelta(2)
+    yesterday = dt.date.today() - dt.timedelta(1)
+    pc = PricingContext(pricing_date=future_date, market=CloseMarket(yesterday))
+    assert pc is not None
+    with pytest.raises(ValueError, match="pricing_date in the future"):
+        PricingContext(pricing_date=future_date)
+
+
 def test_market_data_object():
     coord_val_pair = [
         {'coordinate': {
@@ -55,7 +65,7 @@ def test_market_data_object():
             'mkt_quoting_style': 'ATMRate'}, 'value': 'redacted'},
     ]
     coordinates = {MarketDataCoordinate.from_dict(dic['coordinate']): dic['value'] for dic in coord_val_pair}
-    overlay_market = OverlayMarket(market_data=coordinates)
+    overlay_market = OverlayMarket(base_market=CloseMarket(market_data=coordinates))
 
-    assert overlay_market.market_data[0].coordinate == MarketDataCoordinate.from_dict(coord_val_pair[0]['coordinate'])
+    assert overlay_market.coordinates[0] == MarketDataCoordinate.from_dict(coord_val_pair[0]['coordinate'])
     assert overlay_market.redacted_coordinates[0] == MarketDataCoordinate.from_dict(coord_val_pair[1]['coordinate'])
