@@ -22,7 +22,7 @@ from pandas.testing import assert_series_equal
 from testfixtures import Replacer
 from testfixtures.mock import Mock
 
-from gs_quant.timeseries import EdrDataReference
+from gs_quant.timeseries import VolReference
 from gs_quant.timeseries.backtesting import Basket, basket_series, MqValueError, MqTypeError, RebalFreq, date, \
     DataContext, np
 
@@ -100,7 +100,7 @@ def test_basket_price():
 
     replace = Replacer()
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [_mock_spot_data(), _mock_spot_data_feb()]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
@@ -142,8 +142,11 @@ def test_basket_average_implied_vol():
     implied_vol = x.append(y)
     implied_vol.index.name = 'date'
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
-    mock_data.side_effect = [implied_vol, _mock_spot_data()]
+    mock_spot = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
+    mock_spot.side_effect = [implied_vol.rename(columns={'impliedVolatility': 'spot'})]
+
+    mock_data = replace('gs_quant.api.utils.ThreadPoolManager.run_async', Mock())
+    mock_data.return_value = [implied_vol]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
     mock_asset.return_value = [{'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
@@ -151,11 +154,16 @@ def test_basket_average_implied_vol():
 
     a_basket = Basket(['AAPL UW', 'MSFT UW'], [0.1, 0.9], RebalFreq.DAILY)
     expected = pd.Series([21.0, 21.2, 21.25, 21.6, 22.0, 21.0], index=dates)
-    actual = a_basket.average_implied_volatility('6m', EdrDataReference.DELTA_CALL, 50)
+    actual = a_basket.average_implied_volatility('6m', VolReference.DELTA_CALL, 50)
     assert_series_equal(actual, expected)
 
     with pytest.raises(NotImplementedError):
-        a_basket.average_implied_volatility('6m', EdrDataReference.DELTA_CALL, 50, real_time=True)
+        a_basket.average_implied_volatility('6m', VolReference.DELTA_CALL, 50, real_time=True)
+
+    mock_data.return_value = [pd.DataFrame(), pd.DataFrame()]
+    expected = pd.Series()
+    actual = a_basket.average_implied_volatility('3m', VolReference.FORWARD, 20)  # no data for this
+    assert_series_equal(expected, actual)
 
     replace.restore()
 
@@ -168,8 +176,8 @@ def test_basket_average_realized_vol():
     dates_feb = pd.DatetimeIndex([date(2021, 2, 1), date(2021, 2, 2), date(2021, 2, 3), date(2021, 2, 4),
                                   date(2021, 2, 5), date(2021, 2, 6)])
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
-    mock_data.side_effect = [_mock_spot_data(), _mock_spot_data_feb()]
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
+    mock_data.side_effect = [_mock_spot_data(), _mock_spot_data_feb(), _mock_spot_data_feb()]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
     mock_asset.return_value = [{'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
@@ -196,6 +204,12 @@ def test_basket_average_realized_vol():
     with pytest.raises(NotImplementedError):
         a_basket.average_realized_volatility('2d', real_time=True)
 
+    mock_get_last = replace('gs_quant.timeseries.measures.get_last_for_measure', Mock())
+    mock_get_last.return_value = None
+    # Test case where ts.get_last_for_measure returns none
+    with DataContext('2021-02-01', datetime.date.today() + datetime.timedelta(days=2)):
+        a_basket.average_realized_volatility('2d')
+
     replace.restore()
 
 
@@ -234,7 +248,7 @@ def _mock_spot_data_corr():
 def test_basket_average_realized_vol_wts():
     replace = Replacer()
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [_mock_data_simple()]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
@@ -248,7 +262,7 @@ def test_basket_average_realized_vol_wts():
 
     with DataContext(start=date(2021, 9, 1), end=date(2021, 9, 25)):
         av_realized_vol = a_basket.average_realized_volatility('2d')
-        np.testing.assert_approx_equal(av_realized_vol.iloc[0], 1.7)
+        np.testing.assert_approx_equal(av_realized_vol.iloc[0], 2.3)
 
     replace.restore()
 
@@ -263,7 +277,7 @@ def test_basket_average_realized_vol_intraday():
     z = pd.DataFrame({'spot': (a ** 3).tolist()}, index=a.index)
     z['assetId'] = 'SPX_MOCK_MQID'
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [z]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
@@ -288,14 +302,17 @@ def test_basket_average_realized_corr():
     dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
                               date(2021, 1, 6)])
 
-    mock_data = replace('gs_quant.timeseries.measures.GsDataApi.get_market_data', Mock())
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [_mock_spot_data_identical(), _mock_spot_data_corr(),
                              _mock_spot_data_identical()]
 
     mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
     mock_asset.return_value = [
         {'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
-        {'id': 'MA4B66MW5E27UAL9SUX', 'bbid': 'MSFT UW'}]
+        {'id': 'MA4B66MW5E27UAL9SUX', 'bbid': 'MSFT UW'},
+        {'id': 'ID of a dUpLiCaTe AAPL', 'bbid': 'AAPL UW'}
+
+    ]
 
     a_basket = Basket(['AAPL UW', 'MSFT UW'], [0.1, 0.9], RebalFreq.DAILY)
 
@@ -309,7 +326,9 @@ def test_basket_average_realized_corr():
     mock_asset.return_value = [
         {'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
         {'id': 'MA4B66MW5E27UAL9SUX', 'bbid': 'MSFT UW'},
-        {'id': 'MA4B66MW5E27UANZH2M', 'bbid': 'XLP UP'}]
+        {'id': 'MA4B66MW5E27UANZH2M', 'bbid': 'XLP UP'},
+        {'id': 'ID of a dUpLiCaTe XLP UP', 'bbid': 'XLP UP'}
+    ]
 
     b_basket = Basket(['AAPL UW', 'MSFT UW', 'XLP UP'], [0.2, 0.3, 0.5], RebalFreq.DAILY)
 
@@ -324,7 +343,9 @@ def test_basket_average_realized_corr():
     mock_asset.return_value = [
         {'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
         {'id': 'MA4B66MW5E27UAL9SUX', 'bbid': 'MSFT UW'},
-        {'id': 'MA4B66MW5E27UANZH2M', 'bbid': 'XLP UP'}]
+        {'id': 'MA4B66MW5E27UANZH2M', 'bbid': 'XLP UP'},
+        {'id': 'ID of a DuPlIcAtE MSFT UW', 'bbid': 'MSFT UW'}
+    ]
 
     with pytest.raises(NotImplementedError):
         with DataContext('2021-01-01', '2021-01-09'):
@@ -332,5 +353,33 @@ def test_basket_average_realized_corr():
     replace.restore()
 
 
+def test_basket_without_weights():
+    replace = Replacer()
+
+    mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
+    mock_data.side_effect = [_mock_spot_data(), _mock_spot_data(), _mock_spot_data(), _mock_spot_data()]
+
+    mock_asset = replace('gs_quant.timeseries.backtesting.GsAssetApi.get_many_assets_data', Mock())
+    mock_asset.return_value = [{'id': 'MA4B66MW5E27U9VBB94', 'bbid': 'AAPL UW'},
+                               {'id': 'MA4B66MW5E27UAL9SUX', 'bbid': 'MSFT UW'}]
+
+    a_basket = Basket(['AAPL UW', 'MSFT UW'], [0.5, 0.5], RebalFreq.DAILY)
+    b_basket = Basket(['AAPL UW', 'MSFT UW'])
+
+    with DataContext('2021-01-01', '2021-01-06'):
+        a_price = a_basket.price()
+        b_price = b_basket.price()
+        a_vol = a_basket.average_realized_volatility('2d')
+        b_vol = b_basket.average_realized_volatility('2d')
+    assert_series_equal(a_price, b_price)
+    assert_series_equal(a_vol, b_vol)
+
+    with pytest.raises(MqValueError):
+        c_basket = Basket(['AAPL UW'], [])
+        c_basket.price()
+
+    replace.restore()
+
+
 if __name__ == '__main__':
     pytest.main(args=[__file__])
