@@ -24,12 +24,11 @@ import gs_quant.timeseries.measures_reports as mr
 from gs_quant.api.gs.assets import GsTemporalXRef
 from gs_quant.api.gs.data import MarketDataResponseFrame
 from gs_quant.data.core import DataContext
-from gs_quant.errors import MqValueError, MqError
+from gs_quant.errors import MqValueError
 from gs_quant.markets.report import PerformanceReport, ThematicReport
 from gs_quant.markets.securities import Stock
 from gs_quant.models.risk_model import FactorRiskModel as Factor_Risk_Model
 from gs_quant.target.common import ReportParameters, XRef
-from gs_quant.target.portfolios import RiskAumSource, Portfolio
 from gs_quant.target.reports import Report, PositionSourceType, ReportType
 from gs_quant.target.risk_models import RiskModel, CoverageType, Term, UniverseIdentifier
 
@@ -117,31 +116,114 @@ aggregate_factor_data = [
     }
 ]
 
-ppa_data = {
+constituents_data_l_s = {
+    'assetId': [
+        "MA1",
+        "MA1",
+        "MA1",
+        "MA2",
+        "MA2",
+        "MA2"
+    ],
+    'quantity': [
+        -1,
+        -2,
+        -3,
+        1,
+        2,
+        3
+    ],
     'netExposure': [
         -1,
-        -0.8,
-        -0.6
-    ],
-    'grossExposure': [
+        -2,
+        -3,
         1,
-        1.2,
-        1.4
-    ],
-    'longExposure': [
-        1,
-        1.2,
-        1.4
-    ],
-    'shortExposure': [
-        1,
-        0.8,
-        0.6
+        2,
+        3
     ],
     'pnl': [
-        0.1,
-        0.2,
-        0.2
+        0,
+        -1,
+        -1,
+        0,
+        1,
+        1
+    ],
+    'date': [
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04',
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04'
+    ]
+}
+
+pnl_data_l_s = {
+    'quantity': [
+        -1,
+        -2,
+        -3,
+        -1,
+        -2,
+        -3,
+        1,
+        2,
+        3,
+        1,
+        2,
+        3
+    ],
+    'pnl': [
+        0,
+        -1,
+        -1,
+        0,
+        -1,
+        -1,
+        0,
+        1,
+        1,
+        0,
+        1,
+        1
+    ],
+    'date': [
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04',
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04',
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04',
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04'
+    ]
+}
+
+constituents_data = {
+    'netExposure': [
+        1,
+        2,
+        3
+    ],
+    'assetId': [
+        "MA",
+        "MA",
+        "MA"
+    ],
+    'quantity': [
+        1,
+        1,
+        1
+    ],
+    'pnl': [
+        0,
+        1,
+        1
     ],
     'date': [
         '2020-01-02',
@@ -150,7 +232,33 @@ ppa_data = {
     ]
 }
 
-aum = [{'date': '2020-01-02', 'aum': 2}, {'date': '2020-01-03', 'aum': 2.2}, {'date': '2020-01-04', 'aum': 2.4}]
+constituents_data_s = {
+    'netExposure': [
+        -1,
+        -2,
+        -3
+    ],
+    'assetId': [
+        "MA",
+        "MA",
+        "MA"
+    ],
+    'quantity': [
+        -1,
+        -1,
+        -1
+    ],
+    'pnl': [
+        0,
+        1,
+        1
+    ],
+    'date': [
+        '2020-01-02',
+        '2020-01-03',
+        '2020-01-04'
+    ]
+}
 
 thematic_data = [
     {
@@ -420,121 +528,178 @@ def test_aggregate_factor_support():
 
 def test_normalized_performance():
     idx = pd.date_range('2020-01-02', freq='D', periods=3)
-    expected = {RiskAumSource.Net: pd.Series(data=[1, 1 / 0.8, 1 / 0.6], index=idx,
-                                             name='normalizedPerformance', dtype='float64'),
-                RiskAumSource.Gross: pd.Series(data=[1, 1.2, 1.4], index=idx,
-                                               name='normalizedPerformance', dtype='float64'),
-                RiskAumSource.Long: pd.Series(data=[1, 1.2, 1.4], index=idx,
-                                              name='normalizedPerformance', dtype='float64'),
-                RiskAumSource.Short: pd.Series(data=[1, 1 / 0.8, 1 / 0.6], index=idx,
-                                               name='normalizedPerformance', dtype='float64'),
-                RiskAumSource.Custom_AUM: pd.Series(data=[1, 1.1, 1.2], index=idx,
-                                                    name='normalizedPerformance', dtype='float64')}
+    replace = Replacer()
+    expected = {None: pd.Series(data=[1, 2, 3], index=idx,
+                                name='normalizedPerformance', dtype='float64'),
+                "Long": pd.Series(data=[1, 2, 3], index=idx,
+                                  name='normalizedPerformance', dtype='float64')}
 
-    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
-        for k, v in expected.items():
-            df = MarketDataResponseFrame(data=ppa_data, dtype="float64")
-            replace = Replacer()
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=constituents_data, dtype="float64")
 
-            # mock GsPortfolioApi.get_reports()
-            mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
-            mock.return_value = [
-                Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
-                                  'type': 'Portfolio Performance Analytics',
-                                  'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-            # mock PerformanceReport.get_many_measures()
-            mock = replace('gs_quant.markets.report.PerformanceReport.get_many_measures', Mock())
-            mock.return_value = df
-
-            # mock PerformanceReport.get_custom_aum()
-            mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_custom_aum', Mock())
-            mock.return_value = aum
-
-            # mock PerformanceReport.get()
-            mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
-            mock.return_value = PerformanceReport(report_id='RP1',
-                                                  position_source_type='Portfolio',
-                                                  position_source_id='MP1',
-                                                  report_type='Portfolio Performance Analytics',
-                                                  parameters=ReportParameters(transaction_cost_model='FIXED'))
-
-            actual = mr.normalized_performance('MP1', k.value)
+    for k, v in expected.items():
+        with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+            actual = mr.normalized_performance('MP1', k)
             assert all(actual.values == v.values)
-            replace.restore()
+    replace.restore()
 
 
-def test_normalized_performance_default_aum():
+def test_normalized_performance_short():
     idx = pd.date_range('2020-01-02', freq='D', periods=3)
-    expected = pd.Series(data=[1, 1 / 0.8, 1 / 0.6], index=idx, name='normalizedPerformance', dtype='float64')
+    replace = Replacer()
+    expected = {"Short": pd.Series(data=[1, 1 / 2, 1 / 3], index=idx,
+                                   name='normalizedPerformance', dtype='float64'),
+                "Long": pd.Series(data=[1, 2, 3], index=idx,
+                                  name='normalizedPerformance', dtype='float64'),
+                None: pd.Series(data=[1, (2 + 1 / 2) / 2, (3 + 1 / 3) / 2], index=idx,
+                                name='normalizedPerformance', dtype='float64')}
+
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=constituents_data_l_s, dtype="float64")
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
+    for k, v in expected.items():
+        with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+            actual = mr.normalized_performance('MP1', k)
+            assert all((actual.values - v.values) < 0.01)
+    replace.restore()
+
+
+def test_get_long_pnl():
+    idx = pd.date_range('2020-01-02', freq='D', periods=3)
+    replace = Replacer()
+    expected = pd.Series(data=[0, 2, 2], index=idx, name='longPnl', dtype='float64')
+
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=pnl_data_l_s, dtype="float64")
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
 
     with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
-
-        df = MarketDataResponseFrame(data=ppa_data, dtype="float64")
-        replace = Replacer()
-
-        # mock GsPortfolioApi.get_reports()
-        mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
-        mock.return_value = [
-            Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
-                              'type': 'Portfolio Performance Analytics',
-                              'parameters': {'transactionCostModel': 'FIXED'}})]
-
-        # mock PerformanceReport.get_many_measures()
-        mock = replace('gs_quant.markets.report.PerformanceReport.get_many_measures', Mock())
-        mock.return_value = df
-
-        # mock PerformanceReport.get_custom_aum()
-        mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_custom_aum', Mock())
-        mock.return_value = aum
-
-        # mock PerformanceReport.get()
-        mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
-        mock.return_value = PerformanceReport(report_id='RP1',
-                                              position_source_type='Portfolio',
-                                              position_source_id='MP1',
-                                              report_type='Portfolio Performance Analytics',
-                                              parameters=ReportParameters(transaction_cost_model='FIXED'))
-
-        mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_portfolio', Mock())
-        mock.return_value = Portfolio('USD', 'P1', id_='MP1')
-
-        actual = mr.normalized_performance('MP1', None)
+        actual = mr.long_pnl('MP1')
         assert all(actual.values == expected.values)
-        replace.restore()
+    replace.restore()
 
 
-def test_normalized_performance_no_custom_aum():
+def test_get_short_pnl():
+    idx = pd.date_range('2020-01-02', freq='D', periods=3)
+    replace = Replacer()
+    expected = pd.Series(data=[0, -2, -2], index=idx, name='shortPnl', dtype='float64')
+
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=pnl_data_l_s, dtype="float64")
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
     with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
-        df = MarketDataResponseFrame(data=ppa_data, dtype="float64")
-        replace = Replacer()
+        actual = mr.short_pnl('MP1')
+        assert all(actual.values == expected.values)
+    replace.restore()
 
-        # mock GsPortfolioApi.get_reports()
-        mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
-        mock.return_value = [
-            Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
-                              'type': 'Portfolio Performance Analytics',
-                              'parameters': {'transactionCostModel': 'FIXED'}})]
 
-        # mock PerformanceReport.get_many_measures()
-        mock = replace('gs_quant.markets.report.PerformanceReport.get_many_measures', Mock())
-        mock.return_value = df
+def test_get_short_pnl_empty():
+    replace = Replacer()
+    expected = pd.Series()
 
-        # mock PerformanceReport.get_custom_aum()
-        mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_custom_aum', Mock())
-        mock.return_value = pd.DataFrame({})
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=constituents_data, dtype="float64")
 
-        # mock PerformanceReport.get()
-        mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
-        mock.return_value = PerformanceReport(report_id='RP1',
-                                              position_source_type='Portfolio',
-                                              position_source_id='MP1',
-                                              report_type='Portfolio Performance Analytics',
-                                              parameters=ReportParameters(transaction_cost_model='FIXED'))
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-        with pytest.raises(MqError):
-            mr.normalized_performance('MP1', 'Custom AUM')
-        replace.restore()
+    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+        actual = mr.short_pnl('MP1')
+        assert all(actual.values == expected.values)
+    replace.restore()
+
+
+def test_get_long_pnl_empty():
+    replace = Replacer()
+    expected = pd.Series()
+
+    mock = replace('gs_quant.api.gs.portfolios.GsPortfolioApi.get_reports', Mock())
+    mock.return_value = [
+        Report.from_dict({'id': 'RP1', 'positionSourceType': 'Portfolio', 'positionSourceId': 'MP1',
+                          'type': 'Portfolio Performance Analytics',
+                          'parameters': {'transactionCostModel': 'FIXED'}})]
+    # mock PerformanceReport.get_portfolio_constituents()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_portfolio_constituents', Mock())
+    mock.return_value = MarketDataResponseFrame(data=constituents_data_s, dtype="float64")
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
+    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+        actual = mr.long_pnl('MP1')
+        assert all(actual.values == expected.values)
+    replace.restore()
 
 
 def test_thematic_exposure():
