@@ -18,7 +18,6 @@
 
 import math
 from functools import reduce
-import warnings
 
 from gs_quant.errors import MqTypeError
 from .datetime import *
@@ -612,81 +611,6 @@ def filter_(x: pd.Series, operator: Optional[FilterOperator] = None, value: Opti
     return x
 
 
-@plot_function
-def smooth_spikes(x: pd.Series, threshold: float) -> pd.Series:
-    """
-    Smooth out the spikes of a series. If a point is larger/smaller than (1 +/- threshold) times both neighbors, replace
-    it with the average of those neighbours. Note: the first and last points in the input series are dropped.
-
-    :param x: timeseries
-    :param threshold: minimum increment to trigger filter
-    :return: smoothed timeseries
-
-    **Usage**
-
-    Returns series where values that exceed the threshold relative to both neighbors are replaced.
-
-    **Examples**
-
-    Generate price series and smooth spikes over a threshold of 0.5.
-
-    >>> prices = generate_series(100)
-    >>> smooth_spikes(prices, 0.5)
-
-    **See also**
-
-    :func:`exponential_moving_average`
-    """
-    # Deprecation warning
-    warnings.simplefilter('once')
-    message = "This function will be moved to timeseries.analysis.smooth_spikes on October 1, 2021."
-    warnings.warn(message, DeprecationWarning)
-    warnings.simplefilter('ignore')
-
-    if len(x) < 3:
-        return pd.Series()
-
-    result = x.copy()
-    multiplier = (1 + threshold)
-    current, next_ = x.iloc[0:2]
-    for i in range(1, len(x) - 1):
-        previous = current
-        current = next_
-        next_ = x.iloc[i + 1]
-
-        scaled = current * multiplier
-        if (current > previous * multiplier and current > next_ * multiplier) or (previous > scaled and next_ > scaled):
-            result.iloc[i] = (previous + next_) / 2
-
-    return result[1:-1]
-
-
-@plot_function
-def repeat(x: pd.Series, n: int = 1) -> pd.Series:
-    """
-    Repeats values for days where data is missing. For any date with missing data, the last recorded value is used.
-    Optionally downsamples the result such that there are data points every n days.
-
-    :param x: date-based timeseries
-    :param n: desired frequency of output
-    :return: a timeseries that has been forward-filled, and optionally downsampled
-
-    **Usage**
-
-    Fill missing values with last seen value e.g. to combine daily with weekly or monthly data.
-    """
-    # Deprecation warning
-    message = "This function will be moved to timeseries.analysis.smooth_spikes on October 1, 2021."
-    warnings.simplefilter('once')
-    warnings.warn(message, DeprecationWarning)
-    warnings.simplefilter('ignore')
-
-    if not 0 < n < 367:
-        raise MqValueError('n must be between 0 and 367')
-    index = pd.date_range(freq=f'{n}D', start=x.index[0], end=x.index[-1])
-    return x.reindex(index, method='ffill')
-
-
 def _sum_boolean_series(*series):
     if not 2 <= len(series) <= 100:
         raise MqValueError('expected between 2 and 100 arguments')
