@@ -32,7 +32,7 @@ from gs_quant.errors import MqValueError
 from gs_quant.markets.securities import AssetIdentifier, Asset
 from gs_quant.target.common import Currency as CurrencyEnum, AssetClass, AssetType, PricingLocation
 from gs_quant.timeseries import ASSET_SPEC, BenchmarkType, plot_measure, MeasureDependency, GENERIC_DATE
-from gs_quant.timeseries.helper import _to_offset
+from gs_quant.timeseries.helper import _to_offset, check_forward_looking
 from gs_quant.timeseries.measures import _asset_from_spec, _market_data_timed, _range_from_pricing_date, \
     _get_custom_bd, ExtendedSeries, SwaptionTenorType, _extract_series_from_df
 
@@ -61,8 +61,7 @@ class TdapiRatesDefaultsProvider:
         self.defaults = defaults
         benchmark_mappings = {}
         for k, v in defaults.get("CURRENCIES").items():
-            for e in v:
-                benchmark_mappings[k] = {e.get("benchmarkType"): e.get('floatingRateOption')}
+            benchmark_mappings[k] = {e.get("benchmarkType"): e.get('floatingRateOption') for e in v}
         self.defaults['MAPPING'] = benchmark_mappings
 
     def is_supported(self, currency: CurrencyEnum):
@@ -95,10 +94,21 @@ SWAPTION_DEFAULTS = {
         "USD": [{"benchmarkType": "LIBOR", "floatingRateOption": "USD-LIBOR-BBA", "floatingRateTenor": ["3m", "6m"],
                  "assetIdForAvailabilityCheck": "MAY0X3KRD4AN77E2",
                  "strikeReference": ["ATM"],
-                 "pricingLocation": ["NYC"]}],
+                 "pricingLocation": ["NYC"]},
+                {"benchmarkType": "SOFR", "floatingRateOption": "USD-SOFR-COMPOUND",
+                 "floatingRateTenor": ["1y", "6m", "3m"],
+                 "assetIdForAvailabilityCheck": "MANYJ1AWNEX5C7FY",
+                 "strikeReference": ["ATM"],
+                 "pricingLocation": ["NYC"]}
+                ],
         "GBP": [{"benchmarkType": "LIBOR", "floatingRateOption": "GBP-LIBOR-BBA", "floatingRateTenor": ["6m", "3m"],
                  "assetIdForAvailabilityCheck": "MAX2SBXZRPYR3NTY",
-                 "pricingLocation": ["LDN"]}],
+                 "pricingLocation": ["LDN"]},
+                {"benchmarkType": "SONIA", "floatingRateOption": "GBP-SONIA-COMPOUND",
+                 "floatingRateTenor": ["1y", "6m", "3m"],
+                 "assetIdForAvailabilityCheck": "MAQC2E5J9X6WGGCJ",
+                 "pricingLocation": ["LDN"]}
+                ],
         "AUD": [{"benchmarkType": "BBR", "floatingRateOption": "AUD-BBR-BBSW", "floatingRateTenor": ["6m", "3m"],
                  "assetIdForAvailabilityCheck": "MAQHSC1PAF4X5H4B",
                  "pricingLocation": ["TKO"]}],
@@ -578,7 +588,7 @@ def swap_annuity(asset: Asset, swap_tenor: str, benchmark_type: str = None, floa
                         clearing_house=clearing_house, source=source,
                         real_time=real_time, query_type=QueryType.SWAP_ANNUITY, location=location)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(abs(df['swapAnnuity'] * 1e4 / 1e8))
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(abs(df['swapAnnuity'] * 1e4 / 1e8))
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -999,7 +1009,7 @@ def swaption_vol_smile(asset: Asset, expiration_tenor: str, termination_tenor: s
 
     dataset_ids = getattr(df, 'dataset_ids', ())
     if df.empty:
-        series = ExtendedSeries()
+        series = ExtendedSeries(dtype=float)
     else:
         # convert string ATM+20 to numerical value 20
         df["strikeRelative"] = df["strikeRelative"].apply(lambda d: float(d.split("ATM")[1] if d != "ATM" else 0))
@@ -1041,6 +1051,7 @@ def swaption_vol_term(asset: Asset, tenor_type: SwaptionTenorType, tenor: str, r
     if real_time:
         raise NotImplementedError('realtime swaption_vol not implemented')
 
+    check_forward_looking(pricing_date, source, 'swaption_vol_term')
     currency = CurrencyEnum(asset.get_identifier(AssetIdentifier.BLOOMBERG_ID))
     if location is None:
         location = PricingLocation(swaptions_defaults_provider.get_swaption_parameter(currency, "pricingLocation"))
@@ -1069,7 +1080,7 @@ def swaption_vol_term(asset: Asset, tenor_type: SwaptionTenorType, tenor: str, r
 
     dataset_ids = getattr(df, 'dataset_ids', ())
     if df.empty:
-        series = ExtendedSeries()
+        series = ExtendedSeries(dtype=float)
     else:
         latest = df.index.max()
         _logger.info('selected pricing date %s', latest)
@@ -1079,7 +1090,7 @@ def swaption_vol_term(asset: Asset, tenor_type: SwaptionTenorType, tenor: str, r
         df = df.set_index('expirationDate')
         df.sort_index(inplace=True)
         df = df.loc[DataContext.current.start_date: DataContext.current.end_date]
-        series = ExtendedSeries() if df.empty else ExtendedSeries(df['swaptionVol'])
+        series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['swaptionVol'])
     series.dataset_ids = dataset_ids
     return series
 
@@ -1111,7 +1122,7 @@ def swap_rate(asset: Asset, swap_tenor: str, benchmark_type: str = None, floatin
                         clearing_house=clearing_house, source=source,
                         real_time=real_time, query_type=QueryType.SWAP_RATE, location=location)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['swapRate'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['swapRate'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1214,7 +1225,7 @@ def basis_swap_spread(asset: Asset, swap_tenor: str = '1y',
     _logger.debug('q %s', q)
     df = _market_data_timed(q)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['basisSwapRate'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['basisSwapRate'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1244,6 +1255,7 @@ def swap_term_structure(asset: Asset, benchmark_type: str = None, floating_rate_
     if real_time:
         raise NotImplementedError('realtime swap_rate not implemented')
 
+    check_forward_looking(pricing_date, source, 'swap_term_structure')
     currency = asset.get_identifier(AssetIdentifier.BLOOMBERG_ID)
     currency = CurrencyEnum(currency)
     if currency.value not in CURRENCY_TO_SWAP_RATE_BENCHMARK.keys():
@@ -1293,7 +1305,7 @@ def swap_term_structure(asset: Asset, benchmark_type: str = None, floating_rate_
         df = _market_data_timed(q)
 
     if df.empty:
-        series = ExtendedSeries()
+        series = ExtendedSeries(dtype=float)
     else:
         latest = df.index.max()
         _logger.info('selected pricing date %s', latest)
@@ -1311,7 +1323,7 @@ def swap_term_structure(asset: Asset, benchmark_type: str = None, floating_rate_
             df = df.set_index('expirationDate')
             df.sort_index(inplace=True)
             df = df.loc[DataContext.current.start_date: DataContext.current.end_date]
-            series = ExtendedSeries() if df.empty else ExtendedSeries(df['swapRate'])
+            series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['swapRate'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1346,6 +1358,8 @@ def basis_swap_term_structure(asset: Asset, spread_benchmark_type: str = None, s
     """
     if real_time:
         raise NotImplementedError('realtime basis_swap_rate not implemented')
+    check_forward_looking(pricing_date, source, 'basis_swap_term_structure')
+
     tenor_type = _check_tenor_type(tenor_type)
     tenor_dict = _check_term_structure_tenor(tenor_type=tenor_type, tenor=tenor)
     kwargs = _get_basis_swap_kwargs(asset=asset, spread_benchmark_type=spread_benchmark_type, spread_tenor=spread_tenor,
@@ -1380,7 +1394,7 @@ def basis_swap_term_structure(asset: Asset, spread_benchmark_type: str = None, s
         df = _market_data_timed(q)
 
     if df.empty:
-        series = ExtendedSeries()
+        series = ExtendedSeries(dtype=float)
     else:
         latest = df.index.max()
         _logger.info('selected pricing date %s', latest)
@@ -1398,7 +1412,7 @@ def basis_swap_term_structure(asset: Asset, spread_benchmark_type: str = None, s
             df = df.set_index('expirationDate')
             df.sort_index(inplace=True)
             df = df.loc[DataContext.current.start_date: DataContext.current.end_date]
-            series = ExtendedSeries() if df.empty else ExtendedSeries(df['basisSwapRate'])
+            series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['basisSwapRate'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1446,7 +1460,7 @@ def ois_xccy(asset: Asset, tenor: str = None, *, source: str = None, real_time:
     df = _get_fxfwd_xccy_swp_rates_data(asset=asset, tenor=tenor, query_type=QueryType.OIS_XCCY, source=source,
                                         real_time=real_time)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['oisXccy'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['oisXccy'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1467,7 +1481,7 @@ def ois_xccy_ex_spike(asset: Asset, tenor: str = None, *, source: str = None, re
     df = _get_fxfwd_xccy_swp_rates_data(asset=asset, tenor=tenor, query_type=QueryType.OIS_XCCY_EX_SPIKE, source=source,
                                         real_time=real_time)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['oisXccyExSpike'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['oisXccyExSpike'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1487,7 +1501,7 @@ def non_usd_ois(asset: Asset, tenor: str = None, *, source: str = None, real_tim
     df = _get_fxfwd_xccy_swp_rates_data(asset=asset, tenor=tenor, query_type=QueryType.NON_USD_OIS, source=source,
                                         real_time=real_time)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['nonUsdOis'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['nonUsdOis'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
 
@@ -1507,6 +1521,6 @@ def usd_ois(asset: Asset, tenor: str = None, *, source: str = None, real_time: b
     df = _get_fxfwd_xccy_swp_rates_data(asset=asset, tenor=tenor, query_type=QueryType.USD_OIS, source=source,
                                         real_time=real_time)
 
-    series = ExtendedSeries() if df.empty else ExtendedSeries(df['usdOis'])
+    series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['usdOis'])
     series.dataset_ids = getattr(df, 'dataset_ids', ())
     return series
